searchData={"items":[{"type":"module","doc":"Enviable is a small collection of functions to make working with environment variables\neasier when configuring Elixir projects. It is designed to work configuration\nenvironment loaders like [Dotenvy][] and provides robust value conversion like\n[jetenv][].","title":"Enviable","ref":"Enviable.html"},{"type":"module","doc":"Enviable will typically be imported in `config/runtime.exs` after `Config`, but may be\nused anywhere that environment variables are read.\n\n```elixir\n# config/runtime.exs\nimport Config\nimport Enviable\n\nclient = fetch_env!(\"CLIENT\")\nDotenvy.source([\".env\", \".env.#{client}\", get_env()])\n\n# Before\n#\n# config :my_app,\n#   key: System.fetch_env!(\"SECRET_KEY\"),\n#   port: System.fetch_env!(\"PORT\") |> String.to_integer(),\n#   ssl: System.get_env(\"SSL_ENABLED\") in ~w[1 true]\n\n# After\nconfig :my_app,\n  key: fetch_env!(\"SECRET_KEY\"),\n  port: fetch_env_as_integer!(\"PORT\"),\n  ssl: get_env_as_boolean(\"SSL_ENABLED\")\n```\n\n[dotenvy]: https://hexdocs.pm/dotenvy/readme.html\n[jetenv]: https://hexdocs.pm/jetenv/readme.html","title":"Usage - Enviable","ref":"Enviable.html#module-usage"},{"type":"function","doc":"Deletes an environment variable, removing `varname` from the environment.","title":"Enviable.delete_env/1","ref":"Enviable.html#delete_env/1"},{"type":"function","doc":"Returns the value of the given environment variable or `:error` if not found.\n\nIf the environment variable `varname` is set, then `{:ok, value}` is returned where\nvalue is a string. If `varname` is not set, `:error` is returned.","title":"Enviable.fetch_env/1","ref":"Enviable.html#fetch_env/1"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env(\"PORT\")\n:error\n\niex> Enviable.put_env(\"PORT\", \"4000\")\niex> Enviable.fetch_env(\"PORT\")\n{:ok, \"4000\"}\n```","title":"Examples - Enviable.fetch_env/1","ref":"Enviable.html#fetch_env/1-examples"},{"type":"function","doc":"Returns the value of the given environment variable or raises if not found.\n\nSame as `get_env/1` but raises instead of returning `nil` when the variable is not set.","title":"Enviable.fetch_env!/1","ref":"Enviable.html#fetch_env!/1"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"PORT\", \"4000\")\niex> Enviable.fetch_env!(\"PORT\")\n\"4000\"\n```","title":"Examples - Enviable.fetch_env!/1","ref":"Enviable.html#fetch_env!/1-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to the target `type` as `{:ok,\nterm()}` or `:error` if the variable is unset.\n\nSuported primitive conversions are:\n\n- `:atom` (`t:Enviable.Conversion.convert_atom/0`, `fetch_env_as_atom/2`)\n- `:boolean` (`t:Enviable.Conversion.convert_boolean/0`, `fetch_env_as_boolean/2`)\n- `:charlist` (`t:Enviable.Conversion.convert_charlist/0`, `fetch_env_as_charlist/1`)\n- `:elixir` (`t:Enviable.Conversion.convert_elixir/0`, `fetch_env_as_elixir/1`)\n- `:erlang` (`t:Enviable.Conversion.convert_erlang/0`, `fetch_env_as_erlang/1`)\n- `:float` (`t:Enviable.Conversion.convert_float/0`, `fetch_env_as_float/1`)\n- `:integer` (`t:Enviable.Conversion.convert_integer/0`, `fetch_env_as_integer/2`)\n- `:json` (`t:Enviable.Conversion.convert_json/0`, `fetch_env_as_json/2`)\n- `:log_level` (`t:Enviable.Conversion.convert_log_level/0`, `fetch_env_as_log_level/1`)\n- `:module` (`t:Enviable.Conversion.convert_module/0`, `fetch_env_as_module/2`)\n- `:pem` (`t:Enviable.Conversion.convert_pem/0`, `fetch_env_as_pem/2`)\n- `:safe_atom` (`t:Enviable.Conversion.convert_safe_atom/0`, `fetch_env_as_safe_atom/2`)\n- `:safe_module` (`t:Enviable.Conversion.convert_safe_module/0`,\n  `fetch_env_as_safe_module/2`)\n\nSupported encoded conversions are:\n\n- `:base16` (`t:Enviable.Conversion.encoded_base16/0`, `fetch_env_as_base16/2`)\n- `:base32` (`t:Enviable.Conversion.encoded_base32/0`, `fetch_env_as_base32/2`)\n- `:base64`, `:url_base64` (`t:Enviable.Conversion.encoded_base64/0`,\n  `fetch_env_as_base64/2`, `fetch_env_as_url_base64/2`)\n- `:hex32` (`t:Enviable.Conversion.encoded_hex32/0`, `fetch_env_as_hex32/2`)\n- `:list` (`t:Enviable.Conversion.encoded_list/0`, `fetch_env_as_list/2`)\n\nSee `Enviable.Conversion` for supported type conversions and options, but note that any\n`default` values are ignored for `fetch_env_as/3` and related `fetch_env_as_*`\nfunctions.","title":"Enviable.fetch_env_as/3","ref":"Enviable.html#fetch_env_as/3"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as(\"UNSET\", :atom)\n:error\n\niex> Enviable.fetch_env_as(\"UNSET\", :float)\n:error\n\niex> Enviable.fetch_env_as(\"UNSET\", :base16)\n:error\n\niex> Enviable.put_env(\"NAME\", \"fetch_env_as\")\niex> Enviable.fetch_env_as(\"NAME\", :atom)\n{:ok, :fetch_env_as}\n\niex> Enviable.put_env(\"NAME\", \"FETCH_ENV_AS\")\niex> Enviable.fetch_env_as(\"NAME\", :safe_atom, downcase: true)\n{:ok, :fetch_env_as}\n\niex> Enviable.fetch_env_as(\"UNSET\", :float, default: \"3.5\")\n:error\n\niex> Enviable.fetch_env_as(\"UNSET\", :float, default: 3.5)\n:error\n\niex> Enviable.put_env(\"FLOAT\", \"3\")\niex> Enviable.fetch_env_as(\"FLOAT\", :float)\n{:ok, 3.0}\n\niex> Enviable.put_env(\"FLOAT\", \"3.1\")\niex> Enviable.fetch_env_as(\"FLOAT\", :float)\n{:ok, 3.1}\n\niex> red = Base.encode16(\"RED\", case: :lower)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.fetch_env_as(\"NAME\", :base16, case: :lower)\n{:ok, \"RED\"}\niex> Enviable.fetch_env_as(\"NAME\", {:base16, :string}, case: :lower)\n{:ok, \"RED\"}\niex> Enviable.fetch_env_as(\"NAME\", {:base16, :atom}, case: :lower, downcase: true)\n{:ok, :red}\n```","title":"Examples - Enviable.fetch_env_as/3","ref":"Enviable.html#fetch_env_as/3-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to the target `type` or raises an\nexception if the variable is unset.\n\nSuported primitive conversions are:\n\n- `:atom` (`t:Enviable.Conversion.convert_atom/0`, `fetch_env_as_atom!/2`)\n- `:boolean` (`t:Enviable.Conversion.convert_boolean/0`, `fetch_env_as_boolean!/2`)\n- `:charlist` (`t:Enviable.Conversion.convert_charlist/0`, `fetch_env_as_charlist!/2`)\n- `:elixir` (`t:Enviable.Conversion.convert_elixir/0`, `fetch_env_as_elixir!/1`)\n- `:erlang` (`t:Enviable.Conversion.convert_erlang/0`, `fetch_env_as_erlang!/1`)\n- `:float` (`t:Enviable.Conversion.convert_float/0`, `fetch_env_as_float!/2`)\n- `:integer` (`t:Enviable.Conversion.convert_integer/0`, `fetch_env_as_integer!/2`)\n- `:json` (`t:Enviable.Conversion.convert_json/0`, `fetch_env_as_json!/2`)\n- `:log_level` (`t:Enviable.Conversion.convert_log_level/0`,\n  `fetch_env_as_log_level!/2`)\n- `:module` (`t:Enviable.Conversion.convert_module/0`, `fetch_env_as_module!/2`)\n- `:pem` (`t:Enviable.Conversion.convert_pem/0`, `fetch_env_as_pem!/2`)\n- `:safe_atom` (`t:Enviable.Conversion.convert_safe_atom/0`,\n  `fetch_env_as_safe_atom!/2`)\n- `:safe_module` (`t:Enviable.Conversion.convert_safe_module/0`,\n  `fetch_env_as_safe_module!/2`)\n\nSupported encoded conversions are:\n\n- `:base16` (`t:Enviable.Conversion.encoded_base16/0`, `fetch_env_as_base16!/2`)\n- `:base32` (`t:Enviable.Conversion.encoded_base32/0`, `fetch_env_as_base32!/2`)\n- `:base64`, `:url_base64` (`t:Enviable.Conversion.encoded_base64/0`,\n  `fetch_env_as_base64!/2`, `fetch_env_as_url_base64!/2`)\n- `:hex32` (`t:Enviable.Conversion.encoded_hex32/0`, `fetch_env_as_hex32!/2`)\n- `:list` (`t:Enviable.Conversion.encoded_list/0`, `fetch_env_as_list!/2`)\n\nSee `Enviable.Conversion` for supported type conversions and options, but note that any\ndocumented `default` values are ignored for `fetch_env_as!/3` and related\n`fetch_env_as_*!` functions.","title":"Enviable.fetch_env_as!/3","ref":"Enviable.html#fetch_env_as!/3"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as!(\"UNSET\", :atom)\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.fetch_env_as!(\"UNSET\", :float)\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.fetch_env_as!(\"UNSET\", :base16)\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"NAME\", \"fetch_env_as!\")\niex> Enviable.fetch_env_as!(\"NAME\", :atom)\n:fetch_env_as!\n\niex> Enviable.put_env(\"NAME\", \"FETCH_ENV_AS!\")\niex> Enviable.fetch_env_as!(\"NAME\", :safe_atom, downcase: true)\n:fetch_env_as!\n\niex> Enviable.fetch_env_as!(\"UNSET\", :float, default: \"3.5\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.fetch_env_as!(\"UNSET\", :float, default: 3.5)\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"FLOAT\", \"3\")\niex> Enviable.fetch_env_as!(\"FLOAT\", :float)\n3.0\n\niex> Enviable.put_env(\"FLOAT\", \"3.1\")\niex> Enviable.fetch_env_as!(\"FLOAT\", :float)\n3.1\n\niex> red = Base.encode16(\"RED\", case: :lower)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.fetch_env_as!(\"NAME\", :base16, case: :lower)\n\"RED\"\niex> Enviable.fetch_env_as!(\"NAME\", {:base16, :string}, case: :lower)\n\"RED\"\niex> Enviable.fetch_env_as!(\"NAME\", {:base16, :atom}, case: :lower, downcase: true)\n:red\n```","title":"Examples - Enviable.fetch_env_as!/3","ref":"Enviable.html#fetch_env_as!/3-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to `t:atom/0` as `{:ok, atom()}`\nor `:error` if the variable is unset.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion routine uses `String.to_atom/1` and may result in atom exhaustion if\n> used without the `:allowed` option. See [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working\n> Group of the Erlang Ecosystem Foundation.","title":"Enviable.fetch_env_as_atom/2","ref":"Enviable.html#fetch_env_as_atom/2"},{"type":"function","doc":"- `:allowed`: A list of `t:atom/0` values indicating permitted atoms and used as\n  a lookup table, if present. Any value not found will result in an exception.\n- `:downcase`: See `t:Enviable.Conversion.opt_downcase/0`.","title":"Options - Enviable.fetch_env_as_atom/2","ref":"Enviable.html#fetch_env_as_atom/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_atom(\"UNSET\")\n:error\n\niex> Enviable.put_env(\"NAME\", \"fetch_env_as_atom\")\niex> Enviable.fetch_env_as_atom(\"NAME\")\n{:ok,  :fetch_env_as_atom}\n```","title":"Examples - Enviable.fetch_env_as_atom/2","ref":"Enviable.html#fetch_env_as_atom/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to `t:atom/0` or raises an\nexception if the variable is unset.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion routine uses `String.to_atom/1` and may result in atom exhaustion if\n> used without the `:allowed` option. See [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working\n> Group of the Erlang Ecosystem Foundation.","title":"Enviable.fetch_env_as_atom!/2","ref":"Enviable.html#fetch_env_as_atom!/2"},{"type":"function","doc":"- `:allowed`: A list of `t:atom/0` values indicating permitted atoms and used as\n  a lookup table, if present. Any value not found will result in an exception.\n- `:downcase`: See `t:Enviable.Conversion.opt_downcase/0`.","title":"Options - Enviable.fetch_env_as_atom!/2","ref":"Enviable.html#fetch_env_as_atom!/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_atom!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"NAME\", \"fetch_env_as_atom!\")\niex> Enviable.fetch_env_as_atom!(\"NAME\")\n:fetch_env_as_atom!\n```","title":"Examples - Enviable.fetch_env_as_atom!/2","ref":"Enviable.html#fetch_env_as_atom!/2-examples"},{"type":"function","doc":"Returns the value of an environment variable decoded as a base 16 string.","title":"Enviable.fetch_env_as_base16/2","ref":"Enviable.html#fetch_env_as_base16/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Must conform to the permitted type provided\n  in `:as`.\n- `:case`: The value of `:case` passed to `Base.decode16/2`, which must be `:upper`,\n  `:lower`, or `:mixed`.\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.fetch_env_as_base16/2","ref":"Enviable.html#fetch_env_as_base16/2-options"},{"type":"function","doc":"```elixir\niex> red = Base.encode16(\"RED\", case: :lower)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.fetch_env_as_base16(\"NAME\", case: :lower)\n{:ok, \"RED\"}\niex> Enviable.fetch_env_as_base16(\"NAME\", as: :string, case: :lower)\n{:ok, \"RED\"}\niex> Enviable.fetch_env_as_base16(\"NAME\", as: :atom, case: :lower, downcase: true)\n{:ok, :red}\n```","title":"Examples - Enviable.fetch_env_as_base16/2","ref":"Enviable.html#fetch_env_as_base16/2-examples"},{"type":"function","doc":"Returns the value of an environment variable decoded as a base 16 string.","title":"Enviable.fetch_env_as_base16!/2","ref":"Enviable.html#fetch_env_as_base16!/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Must conform to the permitted type provided\n  in `:as`.\n- `:case`: The value of `:case` passed to `Base.decode16/2`, which must be `:upper`,\n  `:lower`, or `:mixed`.\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.fetch_env_as_base16!/2","ref":"Enviable.html#fetch_env_as_base16!/2-options"},{"type":"function","doc":"```elixir\niex> red = Base.encode16(\"RED\", case: :lower)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.fetch_env_as_base16!(\"NAME\", case: :lower)\n\"RED\"\niex> Enviable.fetch_env_as_base16!(\"NAME\", as: :string, case: :lower)\n\"RED\"\niex> Enviable.fetch_env_as_base16!(\"NAME\", as: :atom, case: :lower, downcase: true)\n:red\n```","title":"Examples - Enviable.fetch_env_as_base16!/2","ref":"Enviable.html#fetch_env_as_base16!/2-examples"},{"type":"function","doc":"Returns the value of an environment variable decoded as a base 32 string.","title":"Enviable.fetch_env_as_base32/2","ref":"Enviable.html#fetch_env_as_base32/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Must conform to the permitted type provided\n  in `:as`.\n- `:case`: The value of `:case` passed to `Base.decode32/2`, which must be `:upper`,\n  `:lower`, or `:mixed`.\n- `:padding`: The boolean value of `:padding` passed to `Base.decode32/2`. The default\n  is `false` (the opposite of `Base.decode32/2`).\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.fetch_env_as_base32/2","ref":"Enviable.html#fetch_env_as_base32/2-options"},{"type":"function","doc":"```elixir\niex> red = Base.encode32(\"RED\", case: :lower)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.fetch_env_as_base32(\"NAME\", case: :lower)\n{:ok, \"RED\"}\niex> Enviable.fetch_env_as_base32(\"NAME\", as: :string, case: :lower)\n{:ok, \"RED\"}\niex> Enviable.fetch_env_as_base32(\"NAME\", as: :atom, case: :lower, downcase: true)\n{:ok, :red}\n```","title":"Examples - Enviable.fetch_env_as_base32/2","ref":"Enviable.html#fetch_env_as_base32/2-examples"},{"type":"function","doc":"Returns the value of an environment variable decoded as a base 32 string.","title":"Enviable.fetch_env_as_base32!/2","ref":"Enviable.html#fetch_env_as_base32!/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Must conform to the permitted type provided\n  in `:as`.\n- `:case`: The value of `:case` passed to `Base.decode32/2`, which must be `:upper`,\n  `:lower`, or `:mixed`.\n- `:padding`: The boolean value of `:padding` passed to `Base.decode32/2`. The default\n  is `false` (the opposite of `Base.decode32/2`).\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.fetch_env_as_base32!/2","ref":"Enviable.html#fetch_env_as_base32!/2-options"},{"type":"function","doc":"```elixir\niex> red = Base.encode32(\"RED\", case: :lower)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.fetch_env_as_base32!(\"NAME\", case: :lower)\n\"RED\"\niex> Enviable.fetch_env_as_base32!(\"NAME\", as: :string, case: :lower)\n\"RED\"\niex> Enviable.fetch_env_as_base32!(\"NAME\", as: :atom, case: :lower, downcase: true)\n:red\n```","title":"Examples - Enviable.fetch_env_as_base32!/2","ref":"Enviable.html#fetch_env_as_base32!/2-examples"},{"type":"function","doc":"Returns the value of an environment variable decoded as a base 64 string.","title":"Enviable.fetch_env_as_base64/2","ref":"Enviable.html#fetch_env_as_base64/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Must conform to the permitted type provided\n  in `:as`.\n- `:ignore_whitespace`: Whether to ignore whitespace values. The default is `true`,\n  the opposite default for both `Base.decode64/2` and `Base.url_decode64/2`.\n- `:padding`: The boolean value of `:padding` passed to `Base.decode64/2`. The default\n  is `false` (the opposite of `Base.decode64/2`).\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.fetch_env_as_base64/2","ref":"Enviable.html#fetch_env_as_base64/2-options"},{"type":"function","doc":"```elixir\niex> red = Base.encode64(\"RED\", padding: true)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.fetch_env_as_base64(\"NAME\", padding: false)\n{:ok, \"RED\"}\niex> Enviable.fetch_env_as_base64(\"NAME\", as: :string, padding: true)\n{:ok, \"RED\"}\niex> Enviable.fetch_env_as_base64(\"NAME\", as: :atom, downcase: true, padding: false)\n{:ok, :red}\n```","title":"Examples - Enviable.fetch_env_as_base64/2","ref":"Enviable.html#fetch_env_as_base64/2-examples"},{"type":"function","doc":"Returns the value of an environment variable decoded as a base 64 string.","title":"Enviable.fetch_env_as_base64!/2","ref":"Enviable.html#fetch_env_as_base64!/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Must conform to the permitted type provided\n  in `:as`.\n- `:ignore_whitespace`: Whether to ignore whitespace values. The default is `true`,\n  the opposite default for both `Base.decode64/2` and `Base.url_decode64/2`.\n- `:padding`: The boolean value of `:padding` passed to `Base.decode64/2`. The default\n  is `false` (the opposite of `Base.decode64/2`).\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.fetch_env_as_base64!/2","ref":"Enviable.html#fetch_env_as_base64!/2-options"},{"type":"function","doc":"```elixir\niex> red = Base.encode64(\"RED\", padding: true)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.fetch_env_as_base64!(\"NAME\", padding: false)\n\"RED\"\niex> Enviable.fetch_env_as_base64!(\"NAME\", as: :string, padding: true)\n\"RED\"\niex> Enviable.fetch_env_as_base64!(\"NAME\", as: :atom, downcase: true, padding: false)\n:red\n```","title":"Examples - Enviable.fetch_env_as_base64!/2","ref":"Enviable.html#fetch_env_as_base64!/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:boolean/0` value as\n`{:ok, boolean()}` or `:error` if the variable is unset.\n\nThis function will always result in a `t:boolean/0` value. Unless configured with\n`truthy` or `falsy`, only the values `\"1\"` and `\"true\"` will be converted to `true` and\nany other value will result in `false`.","title":"Enviable.fetch_env_as_boolean/2","ref":"Enviable.html#fetch_env_as_boolean/2"},{"type":"function","doc":"- `:truthy`: a list of string values to be compared for truth values. If the value of the\n  environment variable matches these values, `true` will be returned; other values will\n  result in `false`. Mutually exclusive with `falsy`.\n\n- `:falsy`: a list of string values to be compared for false values. If the value of the\n  environment variable matches these values, `false` will be returned; other values will\n  result in `true`. Mutually exclusive with `truthy`.\n\n- `:downcase`: either `false` (the default), `true`, or the mode parameter for\n  `String.downcase/2` (`:default`, `:ascii`, `:greek`, or `:turkic`).","title":"Options - Enviable.fetch_env_as_boolean/2","ref":"Enviable.html#fetch_env_as_boolean/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_boolean(\"UNSET\")\n:error\n\niex> Enviable.put_env(\"FLAG\", \"1\")\niex> Enviable.fetch_env_as_boolean(\"FLAG\")\n{:ok, true}\n\niex> Enviable.put_env(\"FLAG\", \"something\")\niex> Enviable.fetch_env_as_boolean(\"FLAG\")\n{:ok, false}\n\niex> Enviable.put_env(\"FLAG\", \"oui\")\niex> Enviable.fetch_env_as_boolean(\"FLAG\", truthy: [\"oui\"])\n{:ok, true}\n\niex> Enviable.put_env(\"FLAG\", \"OUI\")\niex> Enviable.fetch_env_as_boolean(\"FLAG\", truthy: [\"oui\"])\n{:ok, false}\n\niex> Enviable.put_env(\"FLAG\", \"OUI\")\niex> Enviable.fetch_env_as_boolean(\"FLAG\", truthy: [\"oui\"], downcase: true)\n{:ok, true}\n\niex> Enviable.put_env(\"FLAG\", \"NON\")\niex> Enviable.fetch_env_as_boolean(\"FLAG\", falsy: [\"non\"])\n{:ok, true}\n\niex> Enviable.put_env(\"FLAG\", \"NON\")\niex> Enviable.fetch_env_as_boolean(\"FLAG\", falsy: [\"non\"], downcase: true)\n{:ok, false}\n```","title":"Examples - Enviable.fetch_env_as_boolean/2","ref":"Enviable.html#fetch_env_as_boolean/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:boolean/0` value or\nraises an exception if the variable is unset.\n\nThis function will always result in a `t:boolean/0` value. Unless configured with\n`truthy` or `falsy`, only the values `\"1\"` and `\"true\"` will be converted to `true` and\nany other value will result in `false`.","title":"Enviable.fetch_env_as_boolean!/2","ref":"Enviable.html#fetch_env_as_boolean!/2"},{"type":"function","doc":"- `:truthy`: a list of string values to be compared for truth values. If the value of\n  the environment variable matches these values, `true` will be returned; other values\n  will result in `false`. Mutually exclusive with `falsy`.\n\n- `:falsy`: a list of string values to be compared for false values. If the value of the\n  environment variable matches these values, `false` will be returned; other values will\n  result in `true`. Mutually exclusive with `truthy`.\n\n- `:downcase`: either `false` (the default), `true`, or the mode parameter for\n  `String.downcase/2` (`:default`, `:ascii`, `:greek`, or `:turkic`).","title":"Options - Enviable.fetch_env_as_boolean!/2","ref":"Enviable.html#fetch_env_as_boolean!/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_boolean!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"FLAG\", \"1\")\niex> Enviable.fetch_env_as_boolean!(\"FLAG\")\ntrue\n\niex> Enviable.put_env(\"FLAG\", \"something\")\niex> Enviable.fetch_env_as_boolean!(\"FLAG\")\nfalse\n\niex> Enviable.put_env(\"FLAG\", \"oui\")\niex> Enviable.fetch_env_as_boolean!(\"FLAG\", truthy: [\"oui\"])\ntrue\n\niex> Enviable.put_env(\"FLAG\", \"OUI\")\niex> Enviable.fetch_env_as_boolean!(\"FLAG\", truthy: [\"oui\"])\nfalse\n\niex> Enviable.put_env(\"FLAG\", \"OUI\")\niex> Enviable.fetch_env_as_boolean!(\"FLAG\", truthy: [\"oui\"], downcase: true)\ntrue\n\niex> Enviable.put_env(\"FLAG\", \"NON\")\niex> Enviable.fetch_env_as_boolean!(\"FLAG\", falsy: [\"non\"])\ntrue\n\niex> Enviable.put_env(\"FLAG\", \"NON\")\niex> Enviable.fetch_env_as_boolean!(\"FLAG\", falsy: [\"non\"], downcase: true)\nfalse\n```","title":"Examples - Enviable.fetch_env_as_boolean!/2","ref":"Enviable.html#fetch_env_as_boolean!/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:charlist/0` as `{:ok,\ncharlist()}` or `:error` if the variable is unset.","title":"Enviable.fetch_env_as_charlist/1","ref":"Enviable.html#fetch_env_as_charlist/1"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_charlist(\"UNSET\")\n:error\n\niex> Enviable.put_env(\"NAME\", \"fetch_env_as\")\niex> Enviable.fetch_env_as_charlist(\"NAME\")\n{:ok, ~c\"fetch_env_as\"}\n```","title":"Examples - Enviable.fetch_env_as_charlist/1","ref":"Enviable.html#fetch_env_as_charlist/1-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:charlist/0` or raises an\nexception if the variable is unset.","title":"Enviable.fetch_env_as_charlist!/1","ref":"Enviable.html#fetch_env_as_charlist!/1"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_charlist!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"NAME\", \"fetch_env_as\")\niex> Enviable.fetch_env_as_charlist!(\"NAME\")\n~c\"fetch_env_as\"\n```","title":"Examples - Enviable.fetch_env_as_charlist!/1","ref":"Enviable.html#fetch_env_as_charlist!/1-examples"},{"type":"function","doc":"Returns the value of an environment variable parsed and evaluated as Elixir code with\nthe result as `{:ok, term()}`, or `:error` if the environment variable is not set.\n\nThis can be used for tuples, complex map declarations, or other expressions difficult to\nrepresent with other types. Longer code blocks should be encoded as base 64 text and\ndecoded as `{:base64, :elixir}`.\n\n> #### Untrusted Input {: .error}\n>\n> This function parses (with `Code.string_to_quoted/1`) and evaluates (with\n> `Code.eval_quoted/1`) elixir code from environment variables in the context of your\n> application. Do not use this with untrusted input.","title":"Enviable.fetch_env_as_elixir/1","ref":"Enviable.html#fetch_env_as_elixir/1"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_elixir(\"UNSET\")\n:error\n\niex> Enviable.put_env(\"TERM\", \"11000..11100//3\")\niex> Enviable.fetch_env_as_elixir(\"TERM\")\n{:ok, 11000..11100//3}\n```","title":"Examples - Enviable.fetch_env_as_elixir/1","ref":"Enviable.html#fetch_env_as_elixir/1-examples"},{"type":"function","doc":"Returns the value of an environment variable parsed and evaluated as Elixir code with\nthe result , or raises an exception if the environment variable is not set.\n\nThis can be used for tuples, complex map declarations, or other expressions difficult to\nrepresent with other types. Longer code blocks should be encoded as base 64 text and\ndecoded as `{:base64, :elixir}`.\n\n> #### Untrusted Input {: .error}\n>\n> This function parses (with `Code.string_to_quoted/1`) and evaluates (with\n> `Code.eval_quoted/1`) elixir code from environment variables in the context of your\n> application. Do not use this with untrusted input.","title":"Enviable.fetch_env_as_elixir!/1","ref":"Enviable.html#fetch_env_as_elixir!/1"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_elixir!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"TERM\", \"11000..11100//3\")\niex> Enviable.fetch_env_as_elixir!(\"TERM\")\n11000..11100//3\n```","title":"Examples - Enviable.fetch_env_as_elixir!/1","ref":"Enviable.html#fetch_env_as_elixir!/1-examples"},{"type":"function","doc":"Returns the value of an environment variable parsed and evaluated as Erlang code with\nthe result as `{:ok, term()}`, or `:error` if the environment variable is not set.\n\nThis can be used for tuples, complex map declarations, or other expressions difficult to\nrepresent with other types. Longer code blocks should be encoded as base 64 text and\ndecoded as `{:base64, :erlang}`.\n\n> #### Untrusted Input {: .error}\n>\n> This function parses (with `:erl_scan.string/1`) and evaluates (with\n> `:erl_parse.parse_term/1`) Erlang code from environment variables in the\n> context of your application. Do not use this with untrusted input.","title":"Enviable.fetch_env_as_erlang/1","ref":"Enviable.html#fetch_env_as_erlang/1"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_erlang(\"UNSET\")\n:error\n\niex> Enviable.put_env(\"TERM\", \"{ok, true}.\")\niex> Enviable.fetch_env_as_erlang(\"TERM\")\n{:ok, {:ok, true}}\n```","title":"Examples - Enviable.fetch_env_as_erlang/1","ref":"Enviable.html#fetch_env_as_erlang/1-examples"},{"type":"function","doc":"Returns the value of an environment variable parsed and evaluated as Erlang code with\nthe result , or raises an exception if the environment variable is not set.\n\nThis can be used for tuples, complex map declarations, or other expressions difficult to\nrepresent with other types. Longer code blocks should be encoded as base 64 text and\ndecoded as `{:base64, :erlang}`.\n\n> #### Untrusted Input {: .error}\n>\n> This function parses (with `:erl_scan.string/1`) and evaluates (with\n> `:erl_parse.parse_term/1`) Erlang code from environment variables in the\n> context of your application. Do not use this with untrusted input.","title":"Enviable.fetch_env_as_erlang!/1","ref":"Enviable.html#fetch_env_as_erlang!/1"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_erlang!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"TERM\", \"{ok, true}.\")\niex> Enviable.fetch_env_as_erlang!(\"TERM\")\n{:ok, true}\n```","title":"Examples - Enviable.fetch_env_as_erlang!/1","ref":"Enviable.html#fetch_env_as_erlang!/1-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:float/0` value as `{:ok,\nfloat()}` or :error if the variable is unset.","title":"Enviable.fetch_env_as_float/1","ref":"Enviable.html#fetch_env_as_float/1"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_float(\"UNSET\")\n:error\n\niex> Enviable.put_env(\"FLOAT\", \"1\")\niex> Enviable.fetch_env_as_float(\"FLOAT\")\n{:ok, 1.0}\n\niex> Enviable.put_env(\"FLOAT\", \"ff\")\niex> Enviable.fetch_env_as_float(\"FLOAT\")\n** (Enviable.ConversionError) could not convert environment variable \"FLOAT\" to type float\n```","title":"Examples - Enviable.fetch_env_as_float/1","ref":"Enviable.html#fetch_env_as_float/1-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:float/0` value or\n`:error` if the variable is unset.","title":"Enviable.fetch_env_as_float!/1","ref":"Enviable.html#fetch_env_as_float!/1"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_float!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"FLOAT\", \"1\")\niex> Enviable.fetch_env_as_float!(\"FLOAT\")\n1.0\n\niex> Enviable.put_env(\"FLOAT\", \"ff\")\niex> Enviable.fetch_env_as_float!(\"FLOAT\")\n** (Enviable.ConversionError) could not convert environment variable \"FLOAT\" to type float\n```","title":"Examples - Enviable.fetch_env_as_float!/1","ref":"Enviable.html#fetch_env_as_float!/1-examples"},{"type":"function","doc":"Returns the value of an environment variable decoded as a base 32 hex encoded string.","title":"Enviable.fetch_env_as_hex32/2","ref":"Enviable.html#fetch_env_as_hex32/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Must conform to the permitted type provided\n  in `:as`.\n- `:case`: The value of `:case` passed to `Base.hex_decode32/2`, which must be `:upper`,\n  `:lower`, or `:mixed`.\n- `:padding`: The boolean value of `:padding` passed to `hex.decode32/2`. The default\n  is `false` (the opposite of `Base.hex_decode32/2`).\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.fetch_env_as_hex32/2","ref":"Enviable.html#fetch_env_as_hex32/2-options"},{"type":"function","doc":"```elixir\niex> red = Base.hex_encode32(\"RED\", case: :lower)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.fetch_env_as_hex32(\"NAME\", case: :lower)\n{:ok, \"RED\"}\niex> Enviable.fetch_env_as_hex32(\"NAME\", as: :string, case: :lower)\n{:ok, \"RED\"}\niex> Enviable.fetch_env_as_hex32(\"NAME\", as: :atom, case: :lower, downcase: true)\n{:ok, :red}\n```","title":"Examples - Enviable.fetch_env_as_hex32/2","ref":"Enviable.html#fetch_env_as_hex32/2-examples"},{"type":"function","doc":"Returns the value of an environment variable decoded as a base 32 hex encoded string.","title":"Enviable.fetch_env_as_hex32!/2","ref":"Enviable.html#fetch_env_as_hex32!/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Must conform to the permitted type provided\n  in `:as`.\n- `:case`: The value of `:case` passed to `Base.hex_decode32/2`, which must be `:upper`,\n  `:lower`, or `:mixed`.\n- `:padding`: The boolean value of `:padding` passed to `hex.decode32/2`. The default\n  is `false` (the opposite of `Base.hex_decode32/2`).\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.fetch_env_as_hex32!/2","ref":"Enviable.html#fetch_env_as_hex32!/2-options"},{"type":"function","doc":"```elixir\niex> red = Base.hex_encode32(\"RED\", case: :lower)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.fetch_env_as_hex32!(\"NAME\", case: :lower)\n\"RED\"\niex> Enviable.fetch_env_as_hex32!(\"NAME\", as: :string, case: :lower)\n\"RED\"\niex> Enviable.fetch_env_as_hex32!(\"NAME\", as: :atom, case: :lower, downcase: true)\n:red\n```","title":"Examples - Enviable.fetch_env_as_hex32!/2","ref":"Enviable.html#fetch_env_as_hex32!/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:integer/0` value as\n`{:ok, integer()}` or `:error` if the variable is unset.","title":"Enviable.fetch_env_as_integer/2","ref":"Enviable.html#fetch_env_as_integer/2"},{"type":"function","doc":"- `:base`: The base (`2..36`) for integer conversion. Defaults to base `10` like\n  `String.to_integer/2`.\n\nFailure to parse the value of the environment variable will result in an exception.","title":"Options - Enviable.fetch_env_as_integer/2","ref":"Enviable.html#fetch_env_as_integer/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_integer(\"UNSET\")\n:error\n\niex> Enviable.put_env(\"PORT\", \"5432\")\niex> Enviable.fetch_env_as_integer(\"PORT\")\n{:ok, 5432}\n\niex> Enviable.put_env(\"PORT\", \"18eb\")\niex> Enviable.fetch_env_as_integer(\"PORT\")\n** (Enviable.ConversionError) could not convert environment variable \"PORT\" to type integer\n\niex> Enviable.put_env(\"PORT\", \"18EB\")\niex> Enviable.fetch_env_as_integer(\"PORT\", base: 16)\n{:ok, 6379}\n```","title":"Examples - Enviable.fetch_env_as_integer/2","ref":"Enviable.html#fetch_env_as_integer/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:integer/0` value or\nraises an exception if the variable is unset.","title":"Enviable.fetch_env_as_integer!/2","ref":"Enviable.html#fetch_env_as_integer!/2"},{"type":"function","doc":"- `:base`: The base (`2..36`) for integer conversion. Defaults to base `10` like\n  `String.to_integer/2`.\n\nFailure to parse the value of the environment variable will result in an exception.","title":"Options - Enviable.fetch_env_as_integer!/2","ref":"Enviable.html#fetch_env_as_integer!/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_integer!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"PORT\", \"5432\")\niex> Enviable.fetch_env_as_integer!(\"PORT\")\n5432\n\niex> Enviable.put_env(\"PORT\", \"18eb\")\niex> Enviable.fetch_env_as_integer!(\"PORT\")\n** (Enviable.ConversionError) could not convert environment variable \"PORT\" to type integer\n\niex> Enviable.put_env(\"PORT\", \"18EB\")\niex> Enviable.fetch_env_as_integer!(\"PORT\", base: 16)\n6379\n```","title":"Examples - Enviable.fetch_env_as_integer!/2","ref":"Enviable.html#fetch_env_as_integer!/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to\na `t:Enviable.Conversion.json/0` value as `{:ok, Conversion.json()}` or `:error` if the\nvariable is unset.","title":"Enviable.fetch_env_as_json/2","ref":"Enviable.html#fetch_env_as_json/2"},{"type":"function","doc":"- `:engine`: The JSON engine to use. May be provided as a `t:module/0` (which must\n  export `decode/1`) or an arity 1 function. If it produces `{:ok, json_value}` or an\n  expected JSON type result, it will be considered successful. Any other result will be\n  treated as failure.\n\nIf the Erlang/OTP `m::json` module is available, or [json_polyfill][jp] is available,\nit will be used as the default JSON engine. Otherwise, [Jason][jason] will be treated as\nthe default engine. This choice may be overridden with application configuration, as\nthis example shows using [Thoas][thoas].\n\n```elixir\nimport Config\n\nconfig :enviable, :json_engine, :thoas\n```\n\n[jp]: https://hexdocs.pm/json_polyfill/readme.html\n[jason]: https://hexdocs.pm/jason/readme.html\n[thoas]: https://hexdocs.pm/thoas/readme.html","title":"Options - Enviable.fetch_env_as_json/2","ref":"Enviable.html#fetch_env_as_json/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_json(\"UNSET\")\n:error\n\niex> Enviable.put_env(\"JSON\", ~S|[{\"foo\":\"bar\"}]|)\niex> Enviable.fetch_env_as_json(\"JSON\")\n{:ok, [%{\"foo\" => \"bar\"}]}\n\niex> Enviable.put_env(\"JSON\", \"ff\")\niex> Enviable.fetch_env_as_json(\"JSON\")\n** (Enviable.ConversionError) could not convert environment variable \"JSON\" to type json\n```","title":"Examples - Enviable.fetch_env_as_json/2","ref":"Enviable.html#fetch_env_as_json/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to\na `t:Enviable.Conversion.json/0` value or raises an exception if the variable is unset.","title":"Enviable.fetch_env_as_json!/2","ref":"Enviable.html#fetch_env_as_json!/2"},{"type":"function","doc":"- `:engine`: The JSON engine to use. May be provided as a `t:module/0` (which must\n  export `decode/1`) or an arity 1 function. If it produces `{:ok, json_value}` or an\n  expected JSON type result, it will be considered successful. Any other result will be\n  treated as failure.\n\nIf the Erlang/OTP `m::json` module is available, or [json_polyfill][jp] is available,\nit will be used as the default JSON engine. Otherwise, [Jason][jason] will be treated as\nthe default engine. This choice may be overridden with application configuration, as\nthis example shows using [Thoas][thoas].\n\n```elixir\nimport Config\n\nconfig :enviable, :json_engine, :thoas\n```\n\n[jp]: https://hexdocs.pm/json_polyfill/readme.html\n[jason]: https://hexdocs.pm/jason/readme.html\n[thoas]: https://hexdocs.pm/thoas/readme.html","title":"Options - Enviable.fetch_env_as_json!/2","ref":"Enviable.html#fetch_env_as_json!/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_json!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"JSON\", ~S|[{\"foo\":\"bar\"}]|)\niex> Enviable.fetch_env_as_json!(\"JSON\")\n[%{\"foo\" => \"bar\"}]\n\niex> Enviable.put_env(\"JSON\", \"ff\")\niex> Enviable.fetch_env_as_json!(\"JSON\")\n** (Enviable.ConversionError) could not convert environment variable \"JSON\" to type json\n```","title":"Examples - Enviable.fetch_env_as_json!/2","ref":"Enviable.html#fetch_env_as_json!/2-examples"},{"type":"function","doc":"Returns the value of an environment variable parsed as a delimiter-separated list.","title":"Enviable.fetch_env_as_list/2","ref":"Enviable.html#fetch_env_as_list/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Each entry must conform to the permitted\n  type provided in `:as`.\n- `:delimiter`: The delimiter used to separate the list. This must be a pattern accepted\n  by `String.split/3` (a string, a list of strings, a compiled binary pattern, or\n  a regular expression). Defaults to `\",\"`.\n- `:parts`: The maximum number of parts to split into (`t:pos_integer/0` or\n  `:infinity`). Passed to `String.split/3`.\n- `:trim`: A boolean option whether empty entries should be omitted.\n\nWhen the pattern is a regular expression, `Regex.split/3` options are also supported:\n\n- `:on`: specifies which captures to split the string on, and in what order. Defaults to\n  :first which means captures inside the regex do not affect the splitting process.\n- `:include_captures`: when true, includes in the result the matches of the regular\n  expression. The matches are not counted towards the maximum number of parts if\n  combined with the `:parts` option. Defaults to `false`.\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.fetch_env_as_list/2","ref":"Enviable.html#fetch_env_as_list/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.put_env(\"LIST\", \"1,2,3\")\niex> Enviable.fetch_env_as_list(\"LIST\")\n{:ok, [\"1\", \"2\", \"3\"]}\niex> Enviable.fetch_env_as_list(\"LIST\", as: :integer)\n{:ok, [1, 2, 3]}\n\niex> Enviable.put_env(\"LIST\", \"1;2;3\")\niex> Enviable.fetch_env_as_list(\"LIST\", delimiter: \";\")\n{:ok, [\"1\", \"2\", \"3\"]}\niex> Enviable.fetch_env_as_list(\"LIST\", as: :integer, delimiter: \";\")\n{:ok, [1, 2, 3]}\n```","title":"Examples - Enviable.fetch_env_as_list/2","ref":"Enviable.html#fetch_env_as_list/2-examples"},{"type":"function","doc":"Returns the value of an environment variable parsed as a delimiter-separated list.","title":"Enviable.fetch_env_as_list!/2","ref":"Enviable.html#fetch_env_as_list!/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Each entry must conform to the permitted\n  type provided in `:as`.\n- `:delimiter`: The delimiter used to separate the list. This must be a pattern accepted\n  by `String.split/3` (a string, a list of strings, a compiled binary pattern, or\n  a regular expression). Defaults to `\",\"`.\n- `:parts`: The maximum number of parts to split into (`t:pos_integer/0` or\n  `:infinity`). Passed to `String.split/3`.\n- `:trim`: A boolean option whether empty entries should be omitted.\n\nWhen the pattern is a regular expression, `Regex.split/3` options are also supported:\n\n- `:on`: specifies which captures to split the string on, and in what order. Defaults to\n  :first which means captures inside the regex do not affect the splitting process.\n- `:include_captures`: when true, includes in the result the matches of the regular\n  expression. The matches are not counted towards the maximum number of parts if\n  combined with the `:parts` option. Defaults to `false`.\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.fetch_env_as_list!/2","ref":"Enviable.html#fetch_env_as_list!/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.put_env(\"LIST\", \"1,2,3\")\niex> Enviable.fetch_env_as_list!(\"LIST\")\n[\"1\", \"2\", \"3\"]\niex> Enviable.fetch_env_as_list!(\"LIST\", as: :integer)\n[1, 2, 3]\n\niex> Enviable.put_env(\"LIST\", \"1;2;3\")\niex> Enviable.fetch_env_as_list!(\"LIST\", delimiter: \";\")\n[\"1\", \"2\", \"3\"]\niex> Enviable.fetch_env_as_list!(\"LIST\", as: :integer, delimiter: \";\")\n[1, 2, 3]\n```","title":"Examples - Enviable.fetch_env_as_list!/2","ref":"Enviable.html#fetch_env_as_list!/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a log level `t:atom/0` for\n`Logger.configure/1` as `{:ok, atom()}` or `:error` if the variable is unset.","title":"Enviable.fetch_env_as_log_level/1","ref":"Enviable.html#fetch_env_as_log_level/1"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_log_level(\"UNSET\")\n:error\n\niex> Enviable.put_env(\"LOG_LEVEL\", \"critical\")\niex> Enviable.fetch_env_as_log_level(\"LOG_LEVEL\")\n{:ok, :critical}\n```","title":"Examples - Enviable.fetch_env_as_log_level/1","ref":"Enviable.html#fetch_env_as_log_level/1-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a log level `t:atom/0` for\n`Logger.configure/1`  or raises an exception if the variable is unset.","title":"Enviable.fetch_env_as_log_level!/1","ref":"Enviable.html#fetch_env_as_log_level!/1"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_log_level!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"LOG_LEVEL\", \"critical\")\niex> Enviable.fetch_env_as_log_level!(\"LOG_LEVEL\")\n:critical\n```","title":"Examples - Enviable.fetch_env_as_log_level!/1","ref":"Enviable.html#fetch_env_as_log_level!/1-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to `t:module/0` as `{:ok,\nmodule()}` or `:error` if the variable is unset.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion routine uses `Module.concat/1` and may result in atom exhaustion if\n> used without the `:allowed` option. See [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working\n> Group of the Erlang Ecosystem Foundation.","title":"Enviable.fetch_env_as_module/2","ref":"Enviable.html#fetch_env_as_module/2"},{"type":"function","doc":"- `:allowed`: A list of `t:module/0` values indicating permitted module and used as\n  a lookup table, if present. Any value not found will result in an exception.","title":"Options - Enviable.fetch_env_as_module/2","ref":"Enviable.html#fetch_env_as_module/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_module(\"UNSET\")\n:error\n\niex> Enviable.put_env(\"NAME\", \"Enviable\")\niex> Enviable.fetch_env_as_module(\"NAME\")\n{:ok, Elixir.Enviable}\n```","title":"Examples - Enviable.fetch_env_as_module/2","ref":"Enviable.html#fetch_env_as_module/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to `t:module/0` or raises an\nexception if the variable is unset.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion routine uses `Module.concat/1` and may result in atom exhaustion if\n> used without the `:allowed` option. See [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working\n> Group of the Erlang Ecosystem Foundation.","title":"Enviable.fetch_env_as_module!/2","ref":"Enviable.html#fetch_env_as_module!/2"},{"type":"function","doc":"- `:allowed`: A list of `t:module/0` values indicating permitted module and used as\n  a lookup table, if present. Any value not found will result in an exception.","title":"Options - Enviable.fetch_env_as_module!/2","ref":"Enviable.html#fetch_env_as_module!/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_module!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"NAME\", \"Enviable\")\niex> Enviable.fetch_env_as_module!(\"NAME\")\nElixir.Enviable\n```","title":"Examples - Enviable.fetch_env_as_module!/2","ref":"Enviable.html#fetch_env_as_module!/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted from a PEM string through\n`:public_key.pem_decode/1` as `{:ok, value}` or `:error` if the variable is unset.","title":"Enviable.fetch_env_as_pem/2","ref":"Enviable.html#fetch_env_as_pem/2"},{"type":"function","doc":"- `:filter`: Filters the output of `:public_key.pem_decode/1`. Permitted values are\n  `false`, `true`, `:cert`, or `:key`. The default is `true`.\n\n  - `false`: the list is returned without processing, suitable for further processing\n    with `:public_key.pem_entry_decode/2`.\n  - `true`: returns the first unencrypted `:PrivateKeyInfo` found, a list of unencrypted\n    `:Certificate` records, or an empty list.\n  - `:cert`: returns a list of unencrypted `:Certificate` records or raises an\n    exception if none are found.\n  - `:key`: returns the first unencrypted `:PrivateKeyIinfo` record or raises an\n    exception if one is not found.","title":"Options - Enviable.fetch_env_as_pem/2","ref":"Enviable.html#fetch_env_as_pem/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_pem(\"UNSET\")\n:error\n\niex> Enviable.put_env(\"PEM\", \"\")\niex> Enviable.fetch_env_as_pem(\"PEM\")\n{:ok, []}\n```","title":"Examples - Enviable.fetch_env_as_pem/2","ref":"Enviable.html#fetch_env_as_pem/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted from a PEM string through\n`:public_key.pem_decode/1`  or raises an exception if the variable is unset.","title":"Enviable.fetch_env_as_pem!/2","ref":"Enviable.html#fetch_env_as_pem!/2"},{"type":"function","doc":"- `:filter`: Filters the output of `:public_key.pem_decode/1`. Permitted values are\n  `false`, `true`, `:cert`, or `:key`. The default is `true`.\n\n  - `false`: the list is returned without processing, suitable for further processing\n    with `:public_key.pem_entry_decode/2`.\n  - `true`: returns the first unencrypted `:PrivateKeyInfo` found, a list of unencrypted\n    `:Certificate` records, or an empty list.\n  - `:cert`: returns a list of unencrypted `:Certificate` records or raises an\n    exception if none are found.\n  - `:key`: returns the first unencrypted `:PrivateKeyIinfo` record or raises an\n    exception if one is not found.","title":"Options - Enviable.fetch_env_as_pem!/2","ref":"Enviable.html#fetch_env_as_pem!/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_pem!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"PEM\", \"\")\niex> Enviable.fetch_env_as_pem!(\"PEM\")\n[]\n```","title":"Examples - Enviable.fetch_env_as_pem!/2","ref":"Enviable.html#fetch_env_as_pem!/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to an existing `t:atom/0` as\n`{:ok, atom()}` or `:error` if the variable is unset.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion routine uses `String.to_existing_atom/1` which will result in an\n> exception if the resulting atom is not already known and if used without the\n> `:allowed` option. See [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working Group of the\n> Erlang Ecosystem Foundation.","title":"Enviable.fetch_env_as_safe_atom/2","ref":"Enviable.html#fetch_env_as_safe_atom/2"},{"type":"function","doc":"- `:allowed`: A list of `t:atom/0` values indicating permitted atoms and used as\n  a lookup table, if present. Any value not found will result in an exception.\n- `:downcase`: See `t:Enviable.Conversion.opt_downcase/0`.","title":"Options - Enviable.fetch_env_as_safe_atom/2","ref":"Enviable.html#fetch_env_as_safe_atom/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_safe_atom(\"UNSET\")\n:error\n\niex> Enviable.put_env(\"NAME\", \"FETCH_ENV_AS_SAFE_ATOM\")\niex> Enviable.fetch_env_as_safe_atom(\"NAME\", downcase: true)\n{:ok, :fetch_env_as_safe_atom}\n```","title":"Examples - Enviable.fetch_env_as_safe_atom/2","ref":"Enviable.html#fetch_env_as_safe_atom/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to an existing `t:atom/0` or\nraises an exception if the variable is unset.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion routine uses `String.to_existing_atom/1` which will result in an\n> exception if the resulting atom is not already known and if used without the\n> `:allowed` option. See [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working Group of the\n> Erlang Ecosystem Foundation.","title":"Enviable.fetch_env_as_safe_atom!/2","ref":"Enviable.html#fetch_env_as_safe_atom!/2"},{"type":"function","doc":"- `:allowed`: A list of `t:atom/0` values indicating permitted atoms and used as\n  a lookup table, if present. Any value not found will result in an exception.\n- `:downcase`: See `t:Enviable.Conversion.opt_downcase/0`.","title":"Options - Enviable.fetch_env_as_safe_atom!/2","ref":"Enviable.html#fetch_env_as_safe_atom!/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_safe_atom!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"NAME\", \"FETCH_ENV_AS_SAFE_ATOM!\")\niex> Enviable.fetch_env_as_safe_atom!(\"NAME\", downcase: true)\n:fetch_env_as_safe_atom!\n```","title":"Examples - Enviable.fetch_env_as_safe_atom!/2","ref":"Enviable.html#fetch_env_as_safe_atom!/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to `t:module/0` as `{:ok,\nmodule()}` or `:error` if the variable is unset.  The resulting `t:module/0` must\nalready exist.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion routine uses `Module.safe_concat/1` which will result in an exception\n> if the resulting module is not already known and if used without the `:allowed`\n> option. See [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working Group of the Erlang Ecosystem\n> Foundation.","title":"Enviable.fetch_env_as_safe_module/2","ref":"Enviable.html#fetch_env_as_safe_module/2"},{"type":"function","doc":"- `:allowed`: A list of `t:module/0` values indicating permitted module and used as\n  a lookup table, if present. Any value not found will result in an exception.","title":"Options - Enviable.fetch_env_as_safe_module/2","ref":"Enviable.html#fetch_env_as_safe_module/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_safe_module(\"UNSET\")\n:error\n\niex> Enviable.put_env(\"NAME\", \"Enviable\")\niex> Enviable.fetch_env_as_safe_module(\"NAME\")\n{:ok, Elixir.Enviable}\n```","title":"Examples - Enviable.fetch_env_as_safe_module/2","ref":"Enviable.html#fetch_env_as_safe_module/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to `t:module/0` or raises an\nexception if the variable is unset. The resulting `t:module/0` must already exist.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion routine uses `Module.safe_concat/1` which will result in an exception\n> if the resulting module is not already known and if used without the `:allowed`\n> option. See [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working Group of the Erlang Ecosystem\n> Foundation.","title":"Enviable.fetch_env_as_safe_module!/2","ref":"Enviable.html#fetch_env_as_safe_module!/2"},{"type":"function","doc":"- `:allowed`: A list of `t:module/0` values indicating permitted module and used as\n  a lookup table, if present. Any value not found will result in an exception.","title":"Options - Enviable.fetch_env_as_safe_module!/2","ref":"Enviable.html#fetch_env_as_safe_module!/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_as_safe_module!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"NAME\", \"Enviable\")\niex> Enviable.fetch_env_as_safe_module!(\"NAME\")\nElixir.Enviable\n```","title":"Examples - Enviable.fetch_env_as_safe_module!/2","ref":"Enviable.html#fetch_env_as_safe_module!/2-examples"},{"type":"function","doc":"Returns the value of an environment variable decoded as a URL-safe base 64 string.","title":"Enviable.fetch_env_as_url_base64/2","ref":"Enviable.html#fetch_env_as_url_base64/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Must conform to the permitted type provided\n  in `:as`.\n- `:ignore_whitespace`: Whether to ignore whitespace values. The default is `true`,\n  the opposite default for both `Base.decode64/2` and `Base.url_decode64/2`.\n- `:padding`: The boolean value of `:padding` passed to `Base.decode64/2`. The default\n  is `false` (the opposite of `Base.decode64/2`).\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.fetch_env_as_url_base64/2","ref":"Enviable.html#fetch_env_as_url_base64/2-options"},{"type":"function","doc":"```elixir\niex> red = Base.url_encode64(\"RED\", padding: true)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.fetch_env_as_url_base64(\"NAME\", padding: false)\n{:ok, \"RED\"}\niex> Enviable.fetch_env_as_url_base64(\"NAME\", as: :string, padding: true)\n{:ok, \"RED\"}\niex> Enviable.fetch_env_as_url_base64(\"NAME\", as: :atom, downcase: true, padding: false)\n{:ok, :red}\n```","title":"Examples - Enviable.fetch_env_as_url_base64/2","ref":"Enviable.html#fetch_env_as_url_base64/2-examples"},{"type":"function","doc":"Returns the value of an environment variable decoded as a URL-safe base 64 string.","title":"Enviable.fetch_env_as_url_base64!/2","ref":"Enviable.html#fetch_env_as_url_base64!/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Must conform to the permitted type provided\n  in `:as`.\n- `:ignore_whitespace`: Whether to ignore whitespace values. The default is `true`,\n  the opposite default for both `Base.decode64/2` and `Base.url_decode64/2`.\n- `:padding`: The boolean value of `:padding` passed to `Base.decode64/2`. The default\n  is `false` (the opposite of `Base.decode64/2`).\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.fetch_env_as_url_base64!/2","ref":"Enviable.html#fetch_env_as_url_base64!/2-options"},{"type":"function","doc":"```elixir\niex> red = Base.url_encode64(\"RED\", padding: true)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.fetch_env_as_url_base64!(\"NAME\", padding: false)\n\"RED\"\niex> Enviable.fetch_env_as_url_base64!(\"NAME\", as: :string, padding: true)\n\"RED\"\niex> Enviable.fetch_env_as_url_base64!(\"NAME\", as: :atom, downcase: true, padding: false)\n:red\n```","title":"Examples - Enviable.fetch_env_as_url_base64!/2","ref":"Enviable.html#fetch_env_as_url_base64!/2-examples"},{"type":"function","doc":"Returns the value of an environment variable as `{:ok, t:boolean/0}` value or `:error`\nif the variable is unset. See `fetch_env_as_boolean/2` or more details.","title":"Enviable.fetch_env_boolean/2","ref":"Enviable.html#fetch_env_boolean/2"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_boolean(\"UNSET\")\n:error\n\niex> Enviable.put_env(\"FLAG\", \"1\")\niex> Enviable.fetch_env_boolean(\"FLAG\")\n{:ok, true}\n```","title":"Examples - Enviable.fetch_env_boolean/2","ref":"Enviable.html#fetch_env_boolean/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:boolean/0` value or\nraises an exception if the variable is unset. See `fetch_env_as_boolean!/2` for details.\n\n```elixir\niex> Enviable.fetch_env_boolean!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"FLAG\", \"1\")\niex> Enviable.fetch_env_boolean!(\"FLAG\")\ntrue\n```","title":"Enviable.fetch_env_boolean!/2","ref":"Enviable.html#fetch_env_boolean!/2"},{"type":"function","doc":"Returns the value of an environment variable as `{:ok, t:integer/0}` or `:error` if the\nvariable is unset. See `fetch_env_as_integer/2` for details.","title":"Enviable.fetch_env_integer/2","ref":"Enviable.html#fetch_env_integer/2"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_integer(\"UNSET\")\n:error\n\niex> Enviable.put_env(\"PORT\", \"1\")\niex> Enviable.fetch_env_integer(\"PORT\")\n{:ok, 1}\n```","title":"Examples - Enviable.fetch_env_integer/2","ref":"Enviable.html#fetch_env_integer/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:integer/0` value raises\nan exception if the variable is unset. See `fetch_env_as_integer!/2` for details.","title":"Enviable.fetch_env_integer!/2","ref":"Enviable.html#fetch_env_integer!/2"},{"type":"function","doc":"```elixir\niex> Enviable.fetch_env_integer!(\"UNSET\")\n** (System.EnvError) could not fetch environment variable \"UNSET\" because it is not set\n\niex> Enviable.put_env(\"PORT\", \"1\")\niex> Enviable.fetch_env_integer!(\"PORT\")\n1\n```","title":"Examples - Enviable.fetch_env_integer!/2","ref":"Enviable.html#fetch_env_integer!/2-examples"},{"type":"function","doc":"Returns all system environment variables.\n\nThe returned value is a map containing name-value pairs. Variable names and their values\nare strings.","title":"Enviable.get_env/0","ref":"Enviable.html#get_env/0"},{"type":"function","doc":"Returns the value of the given environment variable.\n\nThe returned value of the environment variable `varname` is a string. If the environment\nvariable is not set, returns the string specified in `default` or `nil` if none is\nspecified.","title":"Enviable.get_env/2","ref":"Enviable.html#get_env/2"},{"type":"function","doc":"```elixir\niex> Enviable.get_env(\"PORT\")\nnil\n\niex> Enviable.get_env(\"PORT\", \"4001\")\n\"4001\"\n\niex> Enviable.put_env(\"PORT\", \"4000\")\niex> Enviable.get_env(\"PORT\")\n\"4000\"\niex> Enviable.get_env(\"PORT\", \"4001\")\n\"4000\"\n```","title":"Examples - Enviable.get_env/2","ref":"Enviable.html#get_env/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to the target `type` or a default\nvalue if the variable is unset. If no `default` is provided, `nil` is returned (unless\nconverting to `:boolean`, which will return `false`).\n\nSuported primitive conversions are:\n\n- `:atom` (`t:Enviable.Conversion.convert_atom/0`, `get_env_as_atom/2`)\n- `:boolean` (`t:Enviable.Conversion.convert_boolean/0`, `get_env_as_boolean/2`)\n- `:charlist` (`t:Enviable.Conversion.convert_charlist/0`, `get_env_as_charlist/2`)\n- `:elixir` (`t:Enviable.Conversion.convert_elixir/0`, `get_env_as_elixir/1`)\n- `:erlang` (`t:Enviable.Conversion.convert_erlang/0`, `get_env_as_erlang/1`)\n- `:float` (`t:Enviable.Conversion.convert_float/0`, `get_env_as_float/2`)\n- `:integer` (`t:Enviable.Conversion.convert_integer/0`, `get_env_as_integer/2`)\n- `:json` (`t:Enviable.Conversion.convert_json/0`, `get_env_as_json/2`)\n- `:log_level` (`t:Enviable.Conversion.convert_log_level/0`, `get_env_as_log_level/2`)\n- `:module` (`t:Enviable.Conversion.convert_module/0`, `get_env_as_module/2`)\n- `:pem` (`t:Enviable.Conversion.convert_pem/0`, `get_env_as_pem/2`)\n- `:safe_atom` (`t:Enviable.Conversion.convert_safe_atom/0`, `get_env_as_safe_atom/2`)\n- `:safe_module` (`t:Enviable.Conversion.convert_safe_module/0`,\n  `get_env_as_safe_module/2`)\n\nSupported encoded conversions are:\n\n- `:base16` (`t:Enviable.Conversion.encoded_base16/0`, `get_env_as_base16/2`)\n- `:base32` (`t:Enviable.Conversion.encoded_base32/0`, `get_env_as_base32/2`)\n- `:base64`, `:url_base64` (`t:Enviable.Conversion.encoded_base64/0`,\n  `get_env_as_base64/2`, `get_env_as_url_base64/2`)\n- `:hex32` (`t:Enviable.Conversion.encoded_hex32/0`, `get_env_as_hex32/2`)\n- `:list` (`t:Enviable.Conversion.encoded_list/0`, `get_env_as_list/2`)\n\nSee `Enviable.Conversion` for supported type conversions and options.","title":"Enviable.get_env_as/3","ref":"Enviable.html#get_env_as/3"},{"type":"function","doc":"Value conversion will be applied only to values contained in the requested environment\nvariable. Default values are used only when the environment variable is unset. There is\na meaningful difference between an unset environment variable (where `System.get_env/1`\nwill return `nil`) and an empty environment variable (where `System.get_env/1` returns\n`\"\"`).\n\n```console\n$ FOO= elixir -e 'IO.inspect([foo: System.get_env(\"FOO\"), bar: System.get_env(\"BAR\")])'\n[foo: \"\", bar: nil]\n```","title":"Value Conversion and Default Values - Enviable.get_env_as/3","ref":"Enviable.html#get_env_as/3-value-conversion-and-default-values"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_as(\"UNSET\", :atom)\nnil\n\niex> Enviable.get_env_as(\"UNSET\", :float)\nnil\n\niex> Enviable.get_env_as(\"UNSET\", :base16)\nnil\n\niex> Enviable.put_env(\"NAME\", \"get_env_as\")\niex> Enviable.get_env_as(\"NAME\", :atom)\n:get_env_as\n\niex> Enviable.put_env(\"NAME\", \"GET_ENV_AS\")\niex> Enviable.get_env_as(\"NAME\", :safe_atom, downcase: true)\n:get_env_as\n\niex> Enviable.get_env_as(\"FLOAT\", :float, default: \"3.5\")\n3.5\n\niex> Enviable.get_env_as(\"FLOAT\", :float, default: 3.5)\n3.5\n\niex> Enviable.put_env(\"FLOAT\", \"3\")\niex> Enviable.get_env_as(\"FLOAT\", :float)\n3.0\n\niex> Enviable.put_env(\"FLOAT\", \"3.1\")\niex> Enviable.get_env_as(\"FLOAT\", :float)\n3.1\n\niex> red = Base.encode16(\"RED\", case: :lower)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.get_env_as(\"NAME\", :base16, case: :lower)\n\"RED\"\niex> Enviable.get_env_as(\"NAME\", {:base16, :string}, case: :lower)\n\"RED\"\niex> Enviable.get_env_as(\"NAME\", {:base16, :atom}, case: :lower, downcase: true)\n:red\n\niex> Enviable.put_env(\"LIST\", \"1,2,3\")\niex> Enviable.get_env_as(\"LIST\", :list)\n[\"1\", \"2\", \"3\"]\niex> Enviable.get_env_as(\"LIST\", {:list, :integer})\n[1, 2, 3]\n\niex> Enviable.put_env(\"LIST\", \"1;2;3\")\niex> Enviable.get_env_as(\"LIST\", :list, delimiter: \";\")\n[\"1\", \"2\", \"3\"]\niex> Enviable.get_env_as(\"LIST\", {:list, :integer}, delimiter: \";\")\n[1, 2, 3]\n```","title":"Examples - Enviable.get_env_as/3","ref":"Enviable.html#get_env_as/3-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to `t:atom/0` or a default value\nif the variable is unset. If no `default` is provided, `nil` is returned.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion routine uses `String.to_atom/1` and may result in atom exhaustion if\n> used without the `:allowed` option. See [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working\n> Group of the Erlang Ecosystem Foundation.","title":"Enviable.get_env_as_atom/2","ref":"Enviable.html#get_env_as_atom/2"},{"type":"function","doc":"- `:allowed`: A list of `t:atom/0` values indicating permitted atoms and used as\n  a lookup table, if present. Any value not found will result in an exception.\n- `:default`: The `t:atom/0` or `t:binary/0` value representing the atom value to use if\n  the environment variable is unset (`nil`). If the `:allowed` option is present, the\n  default value must be one of the permitted values.\n- `:downcase`: See `t:Enviable.Conversion.opt_downcase/0`.\n\nA shorthand for the `default` option may be provided as a `t:atom/0` value.","title":"Options - Enviable.get_env_as_atom/2","ref":"Enviable.html#get_env_as_atom/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_as_atom(\"UNSET\")\nnil\n\niex> Enviable.get_env_as_atom(\"UNSET\", :default)\n:default\n\niex> Enviable.get_env_as_atom(\"UNSET\", default: :default)\n:default\n\niex> Enviable.put_env(\"NAME\", \"get_env_as_atom\")\niex> Enviable.get_env_as_atom(\"NAME\")\n:get_env_as_atom\n```","title":"Examples - Enviable.get_env_as_atom/2","ref":"Enviable.html#get_env_as_atom/2-examples"},{"type":"function","doc":"Returns the value of an environment variable decoded as a base 16 string.","title":"Enviable.get_env_as_base16/2","ref":"Enviable.html#get_env_as_base16/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Must conform to the permitted type provided\n  in `:as`.\n- `:case`: The value of `:case` passed to `Base.decode16/2`, which must be `:upper`,\n  `:lower`, or `:mixed`.\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.get_env_as_base16/2","ref":"Enviable.html#get_env_as_base16/2-options"},{"type":"function","doc":"```elixir\niex> red = Base.encode16(\"RED\", case: :lower)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.get_env_as_base16(\"NAME\", case: :lower)\n\"RED\"\niex> Enviable.get_env_as_base16(\"NAME\", as: :string, case: :lower)\n\"RED\"\niex> Enviable.get_env_as_base16(\"NAME\", as: :atom, case: :lower, downcase: true)\n:red\n```","title":"Examples - Enviable.get_env_as_base16/2","ref":"Enviable.html#get_env_as_base16/2-examples"},{"type":"function","doc":"Returns the value of an environment variable decoded as a base 32 string.","title":"Enviable.get_env_as_base32/2","ref":"Enviable.html#get_env_as_base32/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Must conform to the permitted type provided\n  in `:as`.\n- `:case`: The value of `:case` passed to `Base.decode32/2`, which must be `:upper`,\n  `:lower`, or `:mixed`.\n- `:padding`: The boolean value of `:padding` passed to `Base.decode32/2`. The default\n  is `false` (the opposite of `Base.decode32/2`).\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.get_env_as_base32/2","ref":"Enviable.html#get_env_as_base32/2-options"},{"type":"function","doc":"```elixir\niex> red = Base.encode32(\"RED\", case: :lower)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.get_env_as_base32(\"NAME\", case: :lower)\n\"RED\"\niex> Enviable.get_env_as_base32(\"NAME\", as: :string, case: :lower)\n\"RED\"\niex> Enviable.get_env_as_base32(\"NAME\", as: :atom, case: :lower, downcase: true)\n:red\n```","title":"Examples - Enviable.get_env_as_base32/2","ref":"Enviable.html#get_env_as_base32/2-examples"},{"type":"function","doc":"Returns the value of an environment variable decoded as a base 64 string.","title":"Enviable.get_env_as_base64/2","ref":"Enviable.html#get_env_as_base64/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Must conform to the permitted type provided\n  in `:as`.\n- `:ignore_whitespace`: Whether to ignore whitespace values. The default is `true`,\n  the opposite default for both `Base.decode64/2` and `Base.url_decode64/2`.\n- `:padding`: The boolean value of `:padding` passed to `Base.decode64/2`. The default\n  is `false` (the opposite of `Base.decode64/2`).\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.get_env_as_base64/2","ref":"Enviable.html#get_env_as_base64/2-options"},{"type":"function","doc":"```elixir\niex> red = Base.encode64(\"RED\", padding: true)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.get_env_as_base64(\"NAME\", padding: false)\n\"RED\"\niex> Enviable.get_env_as_base64(\"NAME\", as: :string, padding: true)\n\"RED\"\niex> Enviable.get_env_as_base64(\"NAME\", as: :atom, downcase: true, padding: false)\n:red\n```","title":"Examples - Enviable.get_env_as_base64/2","ref":"Enviable.html#get_env_as_base64/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:boolean/0` value, or\na default value if the variable is unset. If no `default` is provided, `false` will be\nreturned.\n\nThis function will always result in a `t:boolean/0` value. Unless configured with\n`truthy` or `falsy`, only the values `\"1\"` and `\"true\"` will be converted to `true` and\nany other value will result in `false`.","title":"Enviable.get_env_as_boolean/2","ref":"Enviable.html#get_env_as_boolean/2"},{"type":"function","doc":"- `:default`: the default value (which must be `true` or `false`) if the variable is\n  unset. In most cases, when `falsy` is provided, `default: true` should also be\n  provided.\n\n- `:truthy`: a list of string values to be compared for truth values. If the value of\n  the environment variable matches these values, `true` will be returned; other values\n  will result in `false`. Mutually exclusive with `falsy`.\n\n- `:falsy`: a list of string values to be compared for false values. If the value of the\n  environment variable matches these values, `false` will be returned; other values will\n  result in `true`. Mutually exclusive with `truthy`.\n\n- `:downcase`: either `false` (the default), `true`, or the mode parameter for\n  `String.downcase/2` (`:default`, `:ascii`, `:greek`, or `:turkic`).\n\nA shorthand value for the `default` option may be provided as a `t:boolean/0` value.","title":"Options - Enviable.get_env_as_boolean/2","ref":"Enviable.html#get_env_as_boolean/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_as_boolean(\"FLAG\")\nfalse\n\niex> Enviable.get_env_as_boolean(\"FLAG\", true)\ntrue\n\niex> Enviable.get_env_as_boolean(\"FLAG\", default: true)\ntrue\n\niex> Enviable.put_env(\"FLAG\", \"1\")\niex> Enviable.get_env_as_boolean(\"FLAG\")\ntrue\n\niex> Enviable.put_env(\"FLAG\", \"something\")\niex> Enviable.get_env_as_boolean(\"FLAG\")\nfalse\n\niex> Enviable.put_env(\"FLAG\", \"oui\")\niex> Enviable.get_env_as_boolean(\"FLAG\", truthy: [\"oui\"])\ntrue\n\niex> Enviable.put_env(\"FLAG\", \"OUI\")\niex> Enviable.get_env_as_boolean(\"FLAG\", truthy: [\"oui\"])\nfalse\niex> Enviable.get_env_as_boolean(\"FLAG\", truthy: [\"oui\"], downcase: true)\ntrue\n\niex> Enviable.put_env(\"FLAG\", \"NON\")\niex> Enviable.get_env_as_boolean(\"FLAG\", falsy: [\"non\"])\ntrue\niex> Enviable.get_env_as_boolean(\"FLAG\", falsy: [\"non\"], downcase: true)\nfalse\n\niex> Enviable.get_env_as_boolean(\"FLAG\", default: nil)\n** (ArgumentError) could not convert environment variable \"FLAG\" to type boolean: non-boolean `default` value\n\niex> Enviable.get_env_as_boolean(\"FLAG\", downcase: nil)\n** (ArgumentError) could not convert environment variable \"FLAG\" to type boolean: invalid `downcase` value\n\niex> Enviable.get_env_as_boolean(\"FLAG\", truthy: [\"oui\"], falsy: [\"non\"])\n** (ArgumentError) could not convert environment variable \"FLAG\" to type boolean: `truthy` and `falsy` options both provided\n```","title":"Examples - Enviable.get_env_as_boolean/2","ref":"Enviable.html#get_env_as_boolean/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:charlist/0` or a default\nvalue if the variable is unset. If no `default` is provided, `nil` is returned.","title":"Enviable.get_env_as_charlist/2","ref":"Enviable.html#get_env_as_charlist/2"},{"type":"function","doc":"- `:default`: The default value, either as a `t:charlist/0` or `t:binary/0`.\n\nA shorthand for the `default` value may be provided as a `t:binary/0` (there is no guard\nfor `t:charlist/0`).","title":"Options - Enviable.get_env_as_charlist/2","ref":"Enviable.html#get_env_as_charlist/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_as_charlist(\"UNDEFINED\")\nnil\n\niex> Enviable.get_env_as_charlist(\"UNDEFINED\", \"default\")\n~c\"default\"\n\niex> Enviable.get_env_as_charlist(\"UNDEFINED\", default: \"default\")\n~c\"default\"\n\niex> Enviable.get_env_as_charlist(\"UNDEFINED\", default: ~c\"default\")\n~c\"default\"\n\niex> Enviable.put_env(\"NAME\", \"get_env_as\")\niex> Enviable.get_env_as_charlist(\"NAME\")\n~c\"get_env_as\"\n```","title":"Examples - Enviable.get_env_as_charlist/2","ref":"Enviable.html#get_env_as_charlist/2-examples"},{"type":"function","doc":"Returns the value of an environment variable parsed and evaluated as Elixir code, or\n`nil` if the environment variable is not set.\n\nThis can be used for tuples, complex map declarations, or other expressions difficult to\nrepresent with other types. Longer code blocks should be encoded as base 64 text and\ndecoded as `{:base64, :elixir}`.\n\n> #### Untrusted Input {: .error}\n>\n> This function parses (with `Code.string_to_quoted/1`) and evaluates (with\n> `Code.eval_quoted/1`) elixir code from environment variables in the context of your\n> application. Do not use this with untrusted input.","title":"Enviable.get_env_as_elixir/1","ref":"Enviable.html#get_env_as_elixir/1"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_as_elixir(\"TERM\")\nnil\n\niex> Enviable.put_env(\"TERM\", \"11000..11100//3\")\niex> Enviable.get_env_as_elixir(\"TERM\")\n11000..11100//3\n```","title":"Examples - Enviable.get_env_as_elixir/1","ref":"Enviable.html#get_env_as_elixir/1-examples"},{"type":"function","doc":"Returns the value of an environment variable parsed and evaluated as Erlang code, or\n`nil` if the environment variable is not set.\n\nThis can be used for tuples, complex map declarations, or other expressions difficult to\nrepresent with other types. Longer code blocks should be encoded as base 64 text and\ndecoded as `{:base64, :erlang}`.\n\n> #### Untrusted Input {: .error}\n>\n> This function parses (with `:erl_scan.string/1`) and evaluates (with\n> `:erl_parse.parse_term/1`) Erlang code from environment variables in the\n> context of your application. Do not use this with untrusted input.","title":"Enviable.get_env_as_erlang/1","ref":"Enviable.html#get_env_as_erlang/1"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_as_erlang(\"TERM\")\nnil\n\niex> Enviable.put_env(\"TERM\", \"{ok, true}.\")\niex> Enviable.get_env_as_erlang(\"TERM\")\n{:ok, true}\n```","title":"Examples - Enviable.get_env_as_erlang/1","ref":"Enviable.html#get_env_as_erlang/1-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:float/0` value or\na default value if the variable is unset. If no `default` is provided, `nil` will be\nreturned.","title":"Enviable.get_env_as_float/2","ref":"Enviable.html#get_env_as_float/2"},{"type":"function","doc":"- `:default`: The default value, either as `t:float/0`, `t:integer/0` (which will be\n  converted to float), or `t:binary/0` (which must parse cleanly as float).\n\nA shorthand for the `default` value may be provided as a `t:float/0`, `t:integer/0`, or\n`t:binary/0` value.","title":"Options - Enviable.get_env_as_float/2","ref":"Enviable.html#get_env_as_float/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_as_float(\"FLOAT\")\nnil\n\niex> Enviable.get_env_as_float(\"FLOAT\", 25.5)\n25.5\n\niex> Enviable.get_env_as_float(\"FLOAT\", 25)\n25.0\n\niex> Enviable.get_env_as_float(\"FLOAT\", \"255\")\n255.0\n\niex> Enviable.get_env_as_float(\"FLOAT\", default: 25.5)\n25.5\n\niex> Enviable.get_env_as_float(\"FLOAT\", default: 25)\n25.0\n\niex> Enviable.get_env_as_float(\"FLOAT\", default: \"255\")\n255.0\n\niex> Enviable.get_env_as_float(\"FLOAT\", default: \"3.5R\")\n** (ArgumentError) could not convert environment variable \"FLOAT\" to type float: non-float `default` value\n\niex> Enviable.put_env(\"FLOAT\", \"1\")\niex> Enviable.get_env_as_float(\"FLOAT\")\n1.0\n\niex> Enviable.put_env(\"FLOAT\", \"ff\")\niex> Enviable.get_env_as_float(\"FLOAT\")\n** (Enviable.ConversionError) could not convert environment variable \"FLOAT\" to type float\n```","title":"Examples - Enviable.get_env_as_float/2","ref":"Enviable.html#get_env_as_float/2-examples"},{"type":"function","doc":"Returns the value of an environment variable decoded as a base 32 hex encoded string.","title":"Enviable.get_env_as_hex32/2","ref":"Enviable.html#get_env_as_hex32/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Must conform to the permitted type provided\n  in `:as`.\n- `:case`: The value of `:case` passed to `Base.hex_decode32/2`, which must be `:upper`,\n  `:lower`, or `:mixed`.\n- `:padding`: The boolean value of `:padding` passed to `hex.decode32/2`. The default\n  is `false` (the opposite of `Base.hex_decode32/2`).\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.get_env_as_hex32/2","ref":"Enviable.html#get_env_as_hex32/2-options"},{"type":"function","doc":"```elixir\niex> red = Base.hex_encode32(\"RED\", case: :lower)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.get_env_as_hex32(\"NAME\", case: :lower)\n\"RED\"\niex> Enviable.get_env_as_hex32(\"NAME\", as: :string, case: :lower)\n\"RED\"\niex> Enviable.get_env_as_hex32(\"NAME\", as: :atom, case: :lower, downcase: true)\n:red\n```","title":"Examples - Enviable.get_env_as_hex32/2","ref":"Enviable.html#get_env_as_hex32/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:integer/0` value or\na default value if the variable is unset. If no `default` is provided, `nil` is\nreturned.","title":"Enviable.get_env_as_integer/2","ref":"Enviable.html#get_env_as_integer/2"},{"type":"function","doc":"- `:base`: The base (`2..36`) for integer conversion. Defaults to base `10` like\n  `String.to_integer/2`.\n- `:default`: the default value, which must be either a binary string value or an\n  integer. If provided as a binary, this will be interpreted according to the `base`\n  option provided.\n\nA shorthand for the `default` value may be provided as a `t:integer/0` or `t:binary/0`\nvalue.\n\nFailure to parse a binary string `default` or the value of the environment variable will\nresult in an exception.","title":"Options - Enviable.get_env_as_integer/2","ref":"Enviable.html#get_env_as_integer/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_as_integer(\"PORT\")\nnil\n\niex> Enviable.get_env_as_integer(\"PORT\", 5432)\n5432\n\niex> Enviable.get_env_as_integer(\"PORT\", \"5432\")\n5432\n\niex> Enviable.get_env_as_integer(\"PORT\", default: 5432)\n5432\n\niex> Enviable.get_env_as_integer(\"PORT\", default: \"5432\")\n5432\n\niex> Enviable.get_env_as_integer(\"PORT\", default: 3.5)\n** (ArgumentError) could not convert environment variable \"PORT\" to type integer: non-integer `default` value\n\niex> Enviable.put_env(\"PORT\", \"5432\")\niex> Enviable.get_env_as_integer(\"PORT\")\n5432\n\niex> Enviable.put_env(\"PORT\", \"18eb\")\niex> Enviable.get_env_as_integer(\"PORT\")\n** (Enviable.ConversionError) could not convert environment variable \"PORT\" to type integer\n\niex> Enviable.put_env(\"PORT\", \"18EB\")\niex> Enviable.get_env_as_integer(\"PORT\", base: 16)\n6379\n```","title":"Examples - Enviable.get_env_as_integer/2","ref":"Enviable.html#get_env_as_integer/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to\na `t:Enviable.Conversion.json/0` value or a default value if the variable is unset. If\nno `default` is provided, `nil` will be returned.","title":"Enviable.get_env_as_json/2","ref":"Enviable.html#get_env_as_json/2"},{"type":"function","doc":"- `:default`: The default value, which may be any valid JSON type.\n- `:engine`: The JSON engine to use. May be provided as a `t:module/0` (which must\n  export `decode/1`) or an arity 1 function. If it produces `{:ok, json_value}` or an\n  expected JSON type result, it will be considered successful. Any other result will be\n  treated as failure.\n\nIf the Erlang/OTP `m::json` module is available, or [json_polyfill][jp] is available,\nit will be used as the default JSON engine. Otherwise, [Jason][jason] will be treated as\nthe default engine. This choice may be overridden with application configuration, as\nthis example shows using [Thoas][thoas].\n\n```elixir\nimport Config\n\nconfig :enviable, :json_engine, :thoas\n```\n\n[jp]: https://hexdocs.pm/json_polyfill/readme.html\n[jason]: https://hexdocs.pm/jason/readme.html\n[thoas]: https://hexdocs.pm/thoas/readme.html","title":"Options - Enviable.get_env_as_json/2","ref":"Enviable.html#get_env_as_json/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_as_json(\"JSON\")\nnil\n\niex> Enviable.get_env_as_json(\"JSON\", default: \"3.5R\")\n\"3.5R\"\n\niex> Enviable.put_env(\"JSON\", ~S|[{\"foo\":\"bar\"}]|)\niex> Enviable.get_env_as_json(\"JSON\")\n[%{\"foo\" => \"bar\"}]\n\niex> Enviable.put_env(\"JSON\", \"ff\")\niex> Enviable.get_env_as_json(\"JSON\")\n** (Enviable.ConversionError) could not convert environment variable \"JSON\" to type json\n```","title":"Examples - Enviable.get_env_as_json/2","ref":"Enviable.html#get_env_as_json/2-examples"},{"type":"function","doc":"Returns the value of an environment variable parsed as a delimiter-separated list.","title":"Enviable.get_env_as_list/2","ref":"Enviable.html#get_env_as_list/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Each entry must conform to the permitted\n  type provided in `:as`.\n- `:delimiter`: The delimiter used to separate the list. This must be a pattern accepted\n  by `String.split/3` (a string, a list of strings, a compiled binary pattern, or\n  a regular expression). Defaults to `\",\"`.\n- `:parts`: The maximum number of parts to split into (`t:pos_integer/0` or\n  `:infinity`). Passed to `String.split/3`.\n- `:trim`: A boolean option whether empty entries should be omitted.\n\nWhen the pattern is a regular expression, `Regex.split/3` options are also supported:\n\n- `:on`: specifies which captures to split the string on, and in what order. Defaults to\n  :first which means captures inside the regex do not affect the splitting process.\n- `:include_captures`: when true, includes in the result the matches of the regular\n  expression. The matches are not counted towards the maximum number of parts if\n  combined with the `:parts` option. Defaults to `false`.\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.get_env_as_list/2","ref":"Enviable.html#get_env_as_list/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.put_env(\"LIST\", \"1,2,3\")\niex> Enviable.get_env_as_list(\"LIST\")\n[\"1\", \"2\", \"3\"]\niex> Enviable.get_env_as_list(\"LIST\", as: :integer)\n[1, 2, 3]\n\niex> Enviable.put_env(\"LIST\", \"1;2;3\")\niex> Enviable.get_env_as_list(\"LIST\", delimiter: \";\")\n[\"1\", \"2\", \"3\"]\niex> Enviable.get_env_as_list(\"LIST\", as: :integer, delimiter: \";\")\n[1, 2, 3]\n```","title":"Examples - Enviable.get_env_as_list/2","ref":"Enviable.html#get_env_as_list/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a log level `t:atom/0` for\n`Logger.configure/1` or a default value if the variable is unset. If no `default` is\nprovided, `nil` will be returned.","title":"Enviable.get_env_as_log_level/2","ref":"Enviable.html#get_env_as_log_level/2"},{"type":"function","doc":"- `:default`: The default value. Must be a valid value.\n\nA shorthand for the `default` option may be provided as a `t:atom/0` or `t:binary/0`\nvalue.","title":"Options - Enviable.get_env_as_log_level/2","ref":"Enviable.html#get_env_as_log_level/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_as_log_level(\"LOG_LEVEL\")\nnil\n\niex> Enviable.get_env_as_log_level(\"LOG_LEVEL\", :error)\n:error\n\niex> Enviable.get_env_as_log_level(\"LOG_LEVEL\", \"info\")\n:info\n\niex> Enviable.get_env_as_log_level(\"LOG_LEVEL\", default: :error)\n:error\n\niex> Enviable.get_env_as_log_level(\"LOG_LEVEL\", default: \"info\")\n:info\n\niex> Enviable.put_env(\"LOG_LEVEL\", \"critical\")\niex> Enviable.get_env_as_log_level(\"LOG_LEVEL\")\n:critical\n```","title":"Examples - Enviable.get_env_as_log_level/2","ref":"Enviable.html#get_env_as_log_level/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to `t:module/0` or a default\nvalue if the variable is unset. If no `default` is provided, `nil` will be returned.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion routine uses `Module.concat/1` and may result in atom exhaustion if\n> used without the `:allowed` option. See [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working\n> Group of the Erlang Ecosystem Foundation.","title":"Enviable.get_env_as_module/2","ref":"Enviable.html#get_env_as_module/2"},{"type":"function","doc":"- `:allowed`: A list of `t:module/0` values indicating permitted module and used as\n  a lookup table, if present. Any value not found will result in an exception.\n- `:default`: The `t:module/0` or `t:binary/0` value representing the atom value to use\n  if the environment variable is unset (`nil`). If the `:allowed` option is present, the\n  default value must be one of the permitted values.\n\nA shorthand for the `default` option may be provided as a `t:atom/0` or `t:binary/0`\nvalue.","title":"Options - Enviable.get_env_as_module/2","ref":"Enviable.html#get_env_as_module/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_as_module(\"UNSET\")\nnil\n\niex> Enviable.get_env_as_module(\"UNSET\", Enviable)\nElixir.Enviable\n\niex> Enviable.put_env(\"NAME\", \"Enviable\")\niex> Enviable.get_env_as_module(\"NAME\")\nElixir.Enviable\n```","title":"Examples - Enviable.get_env_as_module/2","ref":"Enviable.html#get_env_as_module/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted from a PEM string through\n`:public_key.pem_decode/1` or `nil` if the variable is unset.","title":"Enviable.get_env_as_pem/2","ref":"Enviable.html#get_env_as_pem/2"},{"type":"function","doc":"- `:filter`: Filters the output of `:public_key.pem_decode/1`. Permitted values are\n  `false`, `true`, `:cert`, or `:key`. The default is `true`.\n\n  - `false`: the list is returned without processing, suitable for further processing\n    with `:public_key.pem_entry_decode/2`.\n  - `true`: returns the first unencrypted `:PrivateKeyInfo` found, a list of unencrypted\n    `:Certificate` records, or an empty list.\n  - `:cert`: returns a list of unencrypted `:Certificate` records or raises an\n    exception if none are found.\n  - `:key`: returns the first unencrypted `:PrivateKeyIinfo` record or raises an\n    exception if one is not found.","title":"Options - Enviable.get_env_as_pem/2","ref":"Enviable.html#get_env_as_pem/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_as_pem(\"PEM\")\nnil\n\niex> Enviable.put_env(\"PEM\", \"\")\niex> Enviable.get_env_as_pem(\"PEM\")\n[]\n```","title":"Examples - Enviable.get_env_as_pem/2","ref":"Enviable.html#get_env_as_pem/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to an existing `t:atom/0` or\na default value if the variable is unset. If no `default` is provided, `nil` is\nreturned.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion routine uses `String.to_existing_atom/1` which will result in an\n> exception if the resulting atom is not already known and if used without the\n> `:allowed` option. See [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working Group of the\n> Erlang Ecosystem Foundation.","title":"Enviable.get_env_as_safe_atom/2","ref":"Enviable.html#get_env_as_safe_atom/2"},{"type":"function","doc":"- `:allowed`: A list of `t:atom/0` values indicating permitted atoms and used as\n  a lookup table, if present. Any value not found will result in an exception.\n- `:default`: The `t:atom/0` or `t:binary/0` value representing the atom value to use if\n  the environment variable is unset (`nil`). If the `:allowed` option is present, the\n  default value must be one of the permitted values.\n- `:downcase`: See `t:Enviable.Conversion.opt_downcase/0`.\n\nA shorthand for the `default` option may be provided as a `t:atom/0` value.","title":"Options - Enviable.get_env_as_safe_atom/2","ref":"Enviable.html#get_env_as_safe_atom/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_as_safe_atom(\"UNSET\")\nnil\n\niex> Enviable.get_env_as_safe_atom(\"UNSET\", :default)\n:default\n\niex> Enviable.get_env_as_safe_atom(\"UNSET\", default: :default)\n:default\n\niex> Enviable.put_env(\"NAME\", \"GET_ENV_AS_SAFE_ATOM\")\niex> Enviable.get_env_as_safe_atom(\"NAME\", downcase: true)\n:get_env_as_safe_atom\n```","title":"Examples - Enviable.get_env_as_safe_atom/2","ref":"Enviable.html#get_env_as_safe_atom/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to `t:module/0` or a default\nvalue if the variable is unset. If no `default` is provided, `nil` will be returned. The\nresulting `t:module/0` must already exist.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion routine uses `Module.safe_concat/1` which will result in an exception\n> if the resulting module is not already known and if used without the `:allowed`\n> option. See [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working Group of the Erlang Ecosystem\n> Foundation.","title":"Enviable.get_env_as_safe_module/2","ref":"Enviable.html#get_env_as_safe_module/2"},{"type":"function","doc":"- `:allowed`: A list of `t:module/0` values indicating permitted module and used as\n  a lookup table, if present. Any value not found will result in an exception.\n- `:default`: The `t:module/0` or `t:binary/0` value representing the atom value to use\n  if the environment variable is unset (`nil`). If the `:allowed` option is present, the\n  default value must be one of the permitted values.\n\nA shorthand for the `default` option may be provided as a `t:atom/0` or `t:binary/0`\nvalue.","title":"Options - Enviable.get_env_as_safe_module/2","ref":"Enviable.html#get_env_as_safe_module/2-options"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_as_safe_module(\"UNSET\")\nnil\n\niex> Enviable.get_env_as_safe_module(\"UNSET\", Enviable)\nElixir.Enviable\n\niex> Enviable.put_env(\"NAME\", \"Enviable\")\niex> Enviable.get_env_as_safe_module(\"NAME\")\nElixir.Enviable\n```","title":"Examples - Enviable.get_env_as_safe_module/2","ref":"Enviable.html#get_env_as_safe_module/2-examples"},{"type":"function","doc":"Returns the value of an environment variable decoded as a URL-safe base 64 string.","title":"Enviable.get_env_as_url_base64/2","ref":"Enviable.html#get_env_as_url_base64/2"},{"type":"function","doc":"- `:as`: The type of value that the encoded string is to be parsed as once decoded.\n  Must be either `:string` (the same as not providing `as: :string`) or\n  a `t:Conversion.primit/0` value.\n- `:default`: The default value to be used. Must conform to the permitted type provided\n  in `:as`.\n- `:ignore_whitespace`: Whether to ignore whitespace values. The default is `true`,\n  the opposite default for both `Base.decode64/2` and `Base.url_decode64/2`.\n- `:padding`: The boolean value of `:padding` passed to `Base.decode64/2`. The default\n  is `false` (the opposite of `Base.decode64/2`).\n\nIf `:as` is provided, the options for that type may also be provided.","title":"Options - Enviable.get_env_as_url_base64/2","ref":"Enviable.html#get_env_as_url_base64/2-options"},{"type":"function","doc":"```elixir\niex> red = Base.url_encode64(\"RED\", padding: true)\niex> Enviable.put_env(\"NAME\", red)\niex> Enviable.get_env_as_url_base64(\"NAME\", padding: false)\n\"RED\"\niex> Enviable.get_env_as_url_base64(\"NAME\", as: :string, padding: true)\n\"RED\"\niex> Enviable.get_env_as_url_base64(\"NAME\", as: :atom, downcase: true, padding: false)\n:red\n```","title":"Examples - Enviable.get_env_as_url_base64/2","ref":"Enviable.html#get_env_as_url_base64/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:boolean/0` value. See\n`get_env_as_boolean/2` for more details.","title":"Enviable.get_env_boolean/2","ref":"Enviable.html#get_env_boolean/2"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_boolean(\"UNSET\")\nfalse\n```","title":"Examples - Enviable.get_env_boolean/2","ref":"Enviable.html#get_env_boolean/2-examples"},{"type":"function","doc":"Returns the value of an environment variable converted to a `t:integer/0` value or `nil`\nif the variable is not set and a `default` is not provided. See `get_env_as_integer/2`\nfor details.","title":"Enviable.get_env_integer/2","ref":"Enviable.html#get_env_integer/2"},{"type":"function","doc":"```elixir\niex> Enviable.get_env_integer(\"UNSET\")\nnil\n\niex> Enviable.get_env_integer(\"PORT\", default: 255)\n255\n```","title":"Examples - Enviable.get_env_integer/2","ref":"Enviable.html#get_env_integer/2-examples"},{"type":"function","doc":"Sets multiple environment variables.\n\nSets a new value for each environment variable corresponding to each `{key, value}` pair\nin `enum`. Keys and non-nil values are automatically converted to charlists. `nil`\nvalues erase the given keys.\n\nOverall, this is a convenience wrapper around `put_env/2` and `delete_env/2` with\nsupport for different key and value formats.","title":"Enviable.put_env/1","ref":"Enviable.html#put_env/1"},{"type":"function","doc":"Sets an environment variable value.\n\nSets a new `value` for the environment variable `varname`.","title":"Enviable.put_env/2","ref":"Enviable.html#put_env/2"},{"type":"function","doc":"Set an environment variable value only if it is not yet set. This is a convenience\nwrapper around `System.put_env/2` and `System.get_env/2`.","title":"Enviable.put_env_new/2","ref":"Enviable.html#put_env_new/2"},{"type":"function","doc":"```elixir\niex> Enviable.put_env_new(\"PORT\", \"3000\")\n:ok\niex> Enviable.get_env(\"PORT\")\n\"3000\"\niex> Enviable.put_env_new(\"PORT\", \"5000\")\n:ok\niex> Enviable.get_env(\"PORT\")\n\"3000\"\n```","title":"Examples - Enviable.put_env_new/2","ref":"Enviable.html#put_env_new/2-examples"},{"type":"module","doc":"All supported conversions and options for those conversions.","title":"Enviable.Conversion","ref":"Enviable.Conversion.html"},{"type":"type","doc":"","title":"Enviable.Conversion.conversion/0","ref":"Enviable.Conversion.html#t:conversion/0"},{"type":"type","doc":"Indicates a conversion to `t:atom/0`.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion uses `String.to_atom/1` and may result in atom exhaustion if used\n> without the `:allowed` option. See [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working Group\n> of the Erlang Ecosystem Foundation.","title":"Enviable.Conversion.convert_atom/0","ref":"Enviable.Conversion.html#t:convert_atom/0"},{"type":"type","doc":"- `:allowed`: A list of `t:atom/0` values indicating permitted atoms and used as a lookup\n  table, if present. Any value not found will result in an exception.\n- `:default`: The `t:atom/0` or `t:binary/0` value representing the atom value to use if\n  the environment variable is unset (`nil`). If the `:allowed` option is present, the\n  default value must be one of the permitted values.\n- `:downcase`: See `t:opt_downcase/0`.","title":"Options - Enviable.Conversion.convert_atom/0","ref":"Enviable.Conversion.html#t:convert_atom/0-options"},{"type":"type","doc":"Indicates a conversion to `t:boolean/0`. This conversion will always result in a `true`\nor `false` value.","title":"Enviable.Conversion.convert_boolean/0","ref":"Enviable.Conversion.html#t:convert_boolean/0"},{"type":"type","doc":"- `:default`: The default value, which must be `true` or `false`. The default value is\n  `false`.\n- `:downcase`: See `t:opt_downcase/0`.\n- `:truthy`, `:falsy`: Only one of `:truthy` or `:falsy` may be specified. It must be\n  a list of `t:binary/0` values. If neither is specified, the default is `truthy: ~w[1\n  true]`.\n  - `:truthy`: if the value to convert is in this list, the result will be `true`\n  - `:falsy`: if the value to convert is in this list, the result will be `false`","title":"Options - Enviable.Conversion.convert_boolean/0","ref":"Enviable.Conversion.html#t:convert_boolean/0-options"},{"type":"type","doc":"Indicates a conversion to `t:charlist/0`.","title":"Enviable.Conversion.convert_charlist/0","ref":"Enviable.Conversion.html#t:convert_charlist/0"},{"type":"type","doc":"- `:default`: The default value, either as a `t:charlist/0` or `t:binary/0`.","title":"Options - Enviable.Conversion.convert_charlist/0","ref":"Enviable.Conversion.html#t:convert_charlist/0-options"},{"type":"type","doc":"Indicates a conversion from a Elixir code string (`:elixir`) by parsing and evaluating\nthe environment variable value.\n\nThis can be used for tuples, complex map declarations, or other expressions difficult to\nrepresent with other types. Longer code blocks should be encoded as base 64 text and\ndecoded as `{:base64, :elixir}`.\n\n> #### Untrusted Input {: .error}\n>\n> This function parses (with `Code.string_to_quoted/1`) and evaluates (with\n> `Code.eval_quoted/1`) elixir code from environment variables in the context of your\n> application. Do not use this with untrusted input.","title":"Enviable.Conversion.convert_elixir/0","ref":"Enviable.Conversion.html#t:convert_elixir/0"},{"type":"type","doc":"```elixir\niex> Enviable.put_env(\"PORT\", \"11000..11100//3\")\niex> Enviable.get_env_as(\"PORT\", :elixir)\n11000..11100//3\n```","title":"Examples - Enviable.Conversion.convert_elixir/0","ref":"Enviable.Conversion.html#t:convert_elixir/0-examples"},{"type":"type","doc":"Indicates a conversion from a Erlang code string (`:erlang`) by parsing and evaluating\nthe environment variable value.\n\nThis can be used for tuples, complex map declarations, or other expressions difficult to\nrepresent with other types. Longer code blocks should be encoded as base 64 text and\ndecoded as `{:base64, :erlang}`.\n\n> #### Untrusted Input {: .error}\n>\n> This function parses (with `:erl_scan.string/1`) and evaluates (with\n> `:erl_parse.parse_term/1`) Erlang code from environment variables in the\n> context of your application. Do not use this with untrusted input.","title":"Enviable.Conversion.convert_erlang/0","ref":"Enviable.Conversion.html#t:convert_erlang/0"},{"type":"type","doc":"```elixir\niex> Enviable.put_env(\"COLOR\", \"{ok, true}.\")\niex> Enviable.get_env_as(\"COLOR\", :erlang)\n{:ok, true}\n```","title":"Examples - Enviable.Conversion.convert_erlang/0","ref":"Enviable.Conversion.html#t:convert_erlang/0-examples"},{"type":"type","doc":"Indicates a conversion to `t:float/0`.","title":"Enviable.Conversion.convert_float/0","ref":"Enviable.Conversion.html#t:convert_float/0"},{"type":"type","doc":"- `:default`: The default value, either as `t:float/0`, `t:integer/0` (which will be\n  converted to float), or `t:binary/0` (which must parse cleanly as float).","title":"Options - Enviable.Conversion.convert_float/0","ref":"Enviable.Conversion.html#t:convert_float/0-options"},{"type":"type","doc":"Indicates a conversion to `t:integer/0`.","title":"Enviable.Conversion.convert_integer/0","ref":"Enviable.Conversion.html#t:convert_integer/0"},{"type":"type","doc":"- `:base`: The base (an integer value `2..36`). Default is `10`.\n- `:default`: The default value. If specified as a `t:binary/0`, it must be expressed in\n  the `:base` value and convert cleanly to an integer.","title":"Options - Enviable.Conversion.convert_integer/0","ref":"Enviable.Conversion.html#t:convert_integer/0-options"},{"type":"type","doc":"Indicates a conversion from JSON, which may result in `nil`, `t:binary/0`,\n`t:boolean/0`, `t:list/0`, `t:map/0`, or `t:number/0` values.","title":"Enviable.Conversion.convert_json/0","ref":"Enviable.Conversion.html#t:convert_json/0"},{"type":"type","doc":"- `:default`: The default value, which may be any valid JSON type.\n- `:engine`: The JSON engine to use. May be provided as a `t:module/0` (which must\n  export `decode/1`) or an arity 1 function. If it produces `{:ok, json_value}` or an\n  expected JSON type result, it will be considered successful. Any other result will be\n  treated as failure.\n\nIf the Erlang/OTP `m::json` module is available, or [json_polyfill][jp] is available,\nit will be used as the default JSON engine. Otherwise, [Jason][jason] will be treated as\nthe default engine. This choice may be overridden with application configuration, as\nthis example shows using [Thoas][thoas].\n\n```elixir\nimport Config\n\nconfig :enviable, :json_engine, :thoas\n```\n\n[jp]: https://hexdocs.pm/json_polyfill/readme.html\n[jason]: https://hexdocs.pm/jason/readme.html\n[thoas]: https://hexdocs.pm/thoas/readme.html","title":"Options - Enviable.Conversion.convert_json/0","ref":"Enviable.Conversion.html#t:convert_json/0-options"},{"type":"type","doc":"Indicates a conversion to log level `t:atom/0` for `Logger.configure/1`.\n\nThis conversion is always case-insensitive, and the result will be one of `:emergency`,\n`:alert`, `:critical`, `:error`, `:warning`, `:warn`, `:notice`, `:info`, `:debug`,\n`:all`, or `:none`.","title":"Enviable.Conversion.convert_log_level/0","ref":"Enviable.Conversion.html#t:convert_log_level/0"},{"type":"type","doc":"- `:default`: The default atom value. Must be a valid value.","title":"Options - Enviable.Conversion.convert_log_level/0","ref":"Enviable.Conversion.html#t:convert_log_level/0-options"},{"type":"type","doc":"Indicates a conversion to `t:module/0`.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion uses `Module.concat/1` and may result in atom exhaustion if used\n> without the `:allowed` option. See [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working Group\n> of the Erlang Ecosystem Foundation.","title":"Enviable.Conversion.convert_module/0","ref":"Enviable.Conversion.html#t:convert_module/0"},{"type":"type","doc":"- `:allowed`: A list of `t:module/0` values indicating permitted module and used as\n  a lookup table, if present. Any value not found will result in an exception.\n- `:default`: The `t:module/0` or `t:binary/0` value representing the atom value to use\n  if the environment variable is unset (`nil`). If the `:allowed` option is present, the\n  default value must be one of the permitted values.","title":"Options - Enviable.Conversion.convert_module/0","ref":"Enviable.Conversion.html#t:convert_module/0-options"},{"type":"type","doc":"Indicates a conversion from a PEM string through `:public_key.pem_decode/1`.","title":"Enviable.Conversion.convert_pem/0","ref":"Enviable.Conversion.html#t:convert_pem/0"},{"type":"type","doc":"- `:filter`: Filters the output of `:public_key.pem_decode/1`. Permitted values are\n  `false`, `true`, `:cert`, or `:key`. The default is `true`.\n\n  - `false`: the list is returned without processing, suitable for further processing\n    with `:public_key.pem_entry_decode/2`.\n  - `true`: returns the first unencrypted `:PrivateKeyInfo` found, a list of unencrypted\n    `:Certificate` records, or an empty list.\n  - `:cert`: returns a list of unencrypted `:Certificate` records or raises an\n    exception if none are found.\n  - `:key`: returns the first unencrypted `:PrivateKeyIinfo` record or raises an\n    exception if one is not found.","title":"Options - Enviable.Conversion.convert_pem/0","ref":"Enviable.Conversion.html#t:convert_pem/0-options"},{"type":"type","doc":"Indicates a conversion to `t:atom/0`.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion uses `String.to_existing_atom/1` which will result in an exception if\n> the resulting atom is not already known and if used without the `:allowed` option. See\n> [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working Group of the Erlang Ecosystem Foundation.","title":"Enviable.Conversion.convert_safe_atom/0","ref":"Enviable.Conversion.html#t:convert_safe_atom/0"},{"type":"type","doc":"- `:allowed`: A list of `t:atom/0` values indicating permitted atoms and used as a lookup\n  table, if present. Any value not found will result in an exception.\n- `:default`: The `t:atom/0` or `t:binary/0` value representing the atom value to use if\n  the environment variable is unset (`nil`). If the `:allowed` option is present, the\n  default value must be one of the permitted values.\n- `:downcase`: See `t:opt_downcase/0`.","title":"Options - Enviable.Conversion.convert_safe_atom/0","ref":"Enviable.Conversion.html#t:convert_safe_atom/0-options"},{"type":"type","doc":"Indicates a conversion to `t:module/0`.\n\n> #### Untrusted Input {: .warning}\n>\n> This conversion uses `Module.safe_concat/1` which will result in an exception if the\n> resulting module is not already known and if used without the `:allowed` option. See\n> [Preventing atom exhaustion](https://erlef.github.io/security-wg/secure_coding_and_deployment_hardening/atom_exhaustion) from the Security Working Group of the Erlang Ecosystem Foundation.","title":"Enviable.Conversion.convert_safe_module/0","ref":"Enviable.Conversion.html#t:convert_safe_module/0"},{"type":"type","doc":"- `:allowed`: A list of `t:module/0` values indicating permitted module and used as\n  a lookup table, if present. Any value not found will result in an exception.\n- `:default`: The `t:module/0` or `t:binary/0` value representing the atom value to use\n  if the environment variable is unset (`nil`). If the `:allowed` option is present, the\n  default value must be one of the permitted values.","title":"Options - Enviable.Conversion.convert_safe_module/0","ref":"Enviable.Conversion.html#t:convert_safe_module/0-options"},{"type":"type","doc":"","title":"Enviable.Conversion.encoded/0","ref":"Enviable.Conversion.html#t:encoded/0"},{"type":"type","doc":"Decodes the value from a base 16 encoded string. If a secondary type is provided,\na further conversion pass is made using the secondary type.","title":"Enviable.Conversion.encoded_base16/0","ref":"Enviable.Conversion.html#t:encoded_base16/0"},{"type":"type","doc":"- `:case`: The value of `:case` passed to `Base.decode16/2`, which must be `:upper`,\n  `:lower`, or `:mixed`.\n\nIf a secondary type is provided, the options for that type may also be provided.","title":"Options - Enviable.Conversion.encoded_base16/0","ref":"Enviable.Conversion.html#t:encoded_base16/0-options"},{"type":"type","doc":"Decodes the value from a base 32 encoded string. If a secondary type is provided,\na further conversion pass is made using the secondary type.","title":"Enviable.Conversion.encoded_base32/0","ref":"Enviable.Conversion.html#t:encoded_base32/0"},{"type":"type","doc":"- `:case`: The value of `:case` passed to `Base.decode32/2`, which must be `:upper`,\n  `:lower`, or `:mixed`. The default is `:upper`.\n- `:padding`: The boolean value of `:padding` passed to `Base.decode32/2`. The default\n  is `false` (the opposite of `Base.decode32/2`).\n\nIf a secondary type is provided, the options for that type may also be provided.","title":"Options - Enviable.Conversion.encoded_base32/0","ref":"Enviable.Conversion.html#t:encoded_base32/0-options"},{"type":"type","doc":"Decodes the value from a base 64 encoded string. If a secondary type is provided,\na further conversion pass is made using the secondary type.","title":"Enviable.Conversion.encoded_base64/0","ref":"Enviable.Conversion.html#t:encoded_base64/0"},{"type":"type","doc":"- `:ignore_whitespace`: Whether to ignore whitespace values. The default is `true`,\n  the opposite default for both `Base.decode64/2` and `Base.url_decode64/2`.\n- `:padding`: The boolean value of `:padding` passed to `Base.decode64/2`. The default\n  is `false` (the opposite of `Base.decode64/2`).\n\nIf a secondary type is provided, the options for that type may also be provided.","title":"Options - Enviable.Conversion.encoded_base64/0","ref":"Enviable.Conversion.html#t:encoded_base64/0-options"},{"type":"type","doc":"Decodes the value from a base 32 hex encoded string with extended hexadecimal alphabet.\nIf a secondary type is provided, a further conversion pass is made using the secondary\ntype.","title":"Enviable.Conversion.encoded_hex32/0","ref":"Enviable.Conversion.html#t:encoded_hex32/0"},{"type":"type","doc":"- `:case`: The value of `:case` passed to `Base.hex_decode32/2`, which must be `:upper`,\n  `:lower`, or `:mixed`. The default is `:upper`.\n- `:padding`: The boolean value of `:padding` passed to `Base.hex_decode32/2`. The\n  default is `false` (the opposite of `Base.hex_decode32/2`).\n\nIf a secondary type is provided, the options for that type may also be provided.","title":"Options - Enviable.Conversion.encoded_hex32/0","ref":"Enviable.Conversion.html#t:encoded_hex32/0-options"},{"type":"type","doc":"Decodes the value from a string as a delimiter-separated list. If a secondary type is\nprovided, a further conversion pass is made using the secondary type.","title":"Enviable.Conversion.encoded_list/0","ref":"Enviable.Conversion.html#t:encoded_list/0"},{"type":"type","doc":"- `:delimiter`: The delimiter used to separate the list. This must be a pattern accepted\n  by `String.split/3` (a string, a list of strings, a compiled binary pattern, or\n  a regular expression). Defaults to `\",\"`.\n- `:parts`: The maximum number of parts to split into (`t:pos_integer/0` or\n  `:infinity`). Passed to `String.split/3`.\n- `:trim`: A boolean option whether empty entries should be omitted.\n\nWhen the pattern is a regular expression, `Regex.split/3` options are also supported:\n\n- `:on`: specifies which captures to split the string on, and in what order. Defaults to\n  :first which means captures inside the regex do not affect the splitting process.\n- `:include_captures`: when true, includes in the result the matches of the regular\n  expression. The matches are not counted towards the maximum number of parts if\n  combined with the `:parts` option. Defaults to `false`.\n\nIf a secondary type is provided, the options for that type may also be provided.","title":"Options - Enviable.Conversion.encoded_list/0","ref":"Enviable.Conversion.html#t:encoded_list/0-options"},{"type":"type","doc":"A value which can be serialized from JSON.","title":"Enviable.Conversion.json/0","ref":"Enviable.Conversion.html#t:json/0"},{"type":"type","doc":"Supported log levels.","title":"Enviable.Conversion.log_level/0","ref":"Enviable.Conversion.html#t:log_level/0"},{"type":"type","doc":"This option controls a type conversion's case folding mode passed to\n`String.downcase/2`.\n\nThe default is `false`. `true` has the same meaning as `:default`.","title":"Enviable.Conversion.opt_downcase/0","ref":"Enviable.Conversion.html#t:opt_downcase/0"},{"type":"type","doc":"Possible return types for `t:convert_pem/0` conversions.\n\nThe return types are variant on the conversion `:filter` option value:\n\n- `true`: either an unencrypted primary key `t:binary/0`  or a list of unencrypted\n  certificates (`[{:Certificate, ct, :not_encrypted}]`);\n- `false`: an unmodified list of `t::public_key.pem_entry/0`.\n- `:cert`: list of unencrypted certificates (`[{:Certificate, ct, :not_encrypted}]`).\n- `:key`: unencrypted primary key `t:binary/0`\n\nThe default is `true`.","title":"Enviable.Conversion.pem/0","ref":"Enviable.Conversion.html#t:pem/0"},{"type":"type","doc":"","title":"Enviable.Conversion.primitive/0","ref":"Enviable.Conversion.html#t:primitive/0"},{"type":"exception","doc":"An exception raised when a provided environment variable cannot be converted to the\nrequested type.","title":"Enviable.ConversionError","ref":"Enviable.ConversionError.html"},{"type":"extras","doc":"# Enviable\n\n- code :: https://github.com/halostatue/enviable\n- issues :: https://github.com/halostatue/enviable/issues\n\nEnviable is a small collection of functions to make working with environment\nvariables easier when configuring Elixir projects. It is designed to work\nconfiguration environment loaders like [Dotenvy][Dotenvy] and provides robust\nvalue conversion like [jetenv][jetenv].\n\nEnviable 1.4 adds explicit functions for retrieval and conversion of encoded\nvalues and adds a new encoded value, `list`, for delimited lists.","title":"Enviable","ref":"readme.html"},{"type":"extras","doc":"Enviable will typically be imported in `config/runtime.exs` after `Config`, but\nmay be used anywhere that environment variables are read.\n\n```elixir\n# config/runtime.exs\nimport Config\nimport Enviable\n\nclient = fetch_env!(\"CLIENT\")\nDotenvy.source([\".env\", \".env.#{client}\", get_env()])\n\nconfig :my_app,\n  key: fetch_env!(\"SECRET_KEY\"),\n  port: fetch_env_as_integer!(\"PORT\"),\n  ssl: get_env_as_boolean(\"SSL_ENABLED\")\n```","title":"Usage - Enviable","ref":"readme.html#usage"},{"type":"extras","doc":"Enviable can be installed by adding `enviable` to your list of dependencies in\n`mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:enviable, \"~> 1.3\"}\n  ]\nend\n```\n\nDocumentation is found on [HexDocs][docs].","title":"Installation - Enviable","ref":"readme.html#installation"},{"type":"extras","doc":"`Enviable` follows [Semantic Versioning 2.0][semver].\n\n[docs]: https://hexdocs.pm/enviable\n[semver]: http://semver.org/\n[dotenvy]: https://hexdocs.pm/dotenvy/readme.html\n[jetenv]: https://hexdocs.pm/jetenv/readme.html","title":"Semantic Versioning - Enviable","ref":"readme.html#semantic-versioning"},{"type":"extras","doc":"# Contributing\n\nI value contributions to Enviable--bug reports, discussions, feature requests,\nand code contributions. New features should be proposed and discussed in an\n[issue][issues].\n\nBefore contributing patches, please read the [Licence](./LICENCE.md).\n\nEnviable is governed under the [Contributor Covenant Code of Conduct][cccoc].","title":"Contributing","ref":"CONTRIBUTING.md.html"},{"type":"extras","doc":"I have several guidelines to contributing code through pull requests:\n\n- All code changes require tests. In most cases, this will be added or updated\n  unit tests. I use [ExUnit][ExUnit].\n\n- I use code formatters, static analysis tools, and linting to ensure consistent\n  styles and formatting. There should be no warnings output from compile or test\n  run processes. I use `mix compile --warnings-as-errors`, [Credo][Credo], and\n  `mix format` (with [Styler][Styler])\n\n- Proposed changes should be on a thoughtfully-named topic branch and organized\n  into logical commit chunks as appropriate.\n\n- Use [Conventional Commits][conventional] with our\n  [conventions](#commit-conventions).\n\n- Versions must not be updated in pull requests.\n\n- Documentation should be added or updated as appropriate for new or updated\n  functionality.\n\n- New dependencies are discouraged and their addition must be discussed,\n  regardless whether it is a development dependency, optional dependency, or\n  runtime dependency.\n\n- All GitHub Actions checks marked as required must pass before a pull request\n  may be accepted and merged.","title":"Code Guidelines - Contributing","ref":"CONTRIBUTING.md.html#code-guidelines"},{"type":"extras","doc":"Enviable has adopted a variation of the Conventional Commits format for commit\nmessages. The following types are permitted:\n\n| Type    | Purpose                                               |\n| ------- | ----------------------------------------------------- |\n| `feat`  | A new feature                                         |\n| `fix`   | A bug fix                                             |\n| `chore` | A code change that is neither a bug fix nor a feature |\n| `docs`  | Documentation updates                                 |\n| `deps`  | Dependency updates, including GitHub Actions.         |\n\nI encourage the use of [Tim Pope's][tpope-qcm] or [Chris Beam's][cbeams]\nguidelines on the writing of commit messages\n\nI require the use of [git][trailers1] [trailers][trailers2] for specific\nadditional metadata and strongly encourage it for others. The conditionally\nrequired metadata trailers are:\n\n- `Breaking-Change`: if the change is a breaking change. **Do not** use the\n  shorthand form (`feat!(scope)`) or `BREAKING CHANGE`.\n\n- `Signed-off-by`: this is required for all developers except me, as outlined in\n  the [Licence](./LICENCE.md#developer-certificate-of-origin).\n\n- `Fixes` or `Resolves`: If a change fixes one or more open [issues][issues],\n  that issue must be included in the `Fixes` or `Resolves` trailer. Multiple\n  issues should be listed comma separated in the same trailer:\n  `Fixes: #1, #5, #7`, but _may_ appear in separate trailers. While both `Fixes`\n  and `Resolves` are synonyms, only _one_ should be used in a given commit or\n  pull request.\n\n- `Related to`: If a change does not fix an issue, those issue references should\n  be included in this trailer.","title":"Commit Conventions - Contributing","ref":"CONTRIBUTING.md.html#commit-conventions"},{"type":"extras","doc":"Austin Ziegler created Enviable.\n\n[cccoc]: ./CODE_OF_CONDUCT.md\n[conventional]: https://www.conventionalcommits.org/en/v1.0.0/\n[credo]: https://github.com/rrrene/credo\n[styler]: https://github.com/adobe/styler\n[exunit]: https://hexdocs.pm/ex_unit/ExUnit.html\n[trailers1]: https://git-scm.com/docs/git-interpret-trailers\n[trailers2]: https://git-scm.com/docs/git-commit#Documentation/git-commit.txt---trailerlttokengtltvaluegt\n[issues]: https://github.com/halostatue/enviable/issues\n[tpope-qcm]: http://tbaggery.com/2008/04/19/a-note-about-git-commit-messages.html\n[cbeams]: https://cbea.ms/git-commit/","title":"Contributors - Contributing","ref":"CONTRIBUTING.md.html#contributors"},{"type":"extras","doc":"# Contributor Covenant Code of Conduct","title":"Code of Conduct","ref":"CODE_OF_CONDUCT.md.html"},{"type":"extras","doc":"We as members, contributors, and leaders pledge to make participation in our\ncommunity a harassment-free experience for everyone, regardless of age, body\nsize, visible or invisible disability, ethnicity, sex characteristics, gender\nidentity and expression, level of experience, education, socio-economic status,\nnationality, personal appearance, race, caste, color, religion, or sexual\nidentity and orientation.\n\nWe pledge to act and interact in ways that contribute to an open, welcoming,\ndiverse, inclusive, and healthy community.","title":"Our Pledge - Code of Conduct","ref":"CODE_OF_CONDUCT.md.html#our-pledge"},{"type":"extras","doc":"Examples of behavior that contributes to a positive environment for our\ncommunity include:\n\n- Demonstrating empathy and kindness toward other people\n- Being respectful of differing opinions, viewpoints, and experiences\n- Giving and gracefully accepting constructive feedback\n- Accepting responsibility and apologizing to those affected by our mistakes,\n  and learning from the experience\n- Focusing on what is best not just for us as individuals, but for the overall\n  community\n\nExamples of unacceptable behavior include:\n\n- The use of sexualized language or imagery, and sexual attention or advances of\n  any kind\n- Trolling, insulting or derogatory comments, and personal or political attacks\n- Public or private harassment\n- Publishing others' private information, such as a physical or email address,\n  without their explicit permission\n- Other conduct which could reasonably be considered inappropriate in a\n  professional setting","title":"Our Standards - Code of Conduct","ref":"CODE_OF_CONDUCT.md.html#our-standards"},{"type":"extras","doc":"Community leaders are responsible for clarifying and enforcing our standards of\nacceptable behavior and will take appropriate and fair corrective action in\nresponse to any behavior that they deem inappropriate, threatening, offensive,\nor harmful.\n\nCommunity leaders have the right and responsibility to remove, edit, or reject\ncomments, commits, code, wiki edits, issues, and other contributions that are\nnot aligned to this Code of Conduct, and will communicate reasons for moderation\ndecisions when appropriate.","title":"Enforcement Responsibilities - Code of Conduct","ref":"CODE_OF_CONDUCT.md.html#enforcement-responsibilities"},{"type":"extras","doc":"This Code of Conduct applies within all community spaces, and also applies when\nan individual is officially representing the community in public spaces.\nExamples of representing our community include using an official email address,\nposting via an official social media account, or acting as an appointed\nrepresentative at an online or offline event.","title":"Scope - Code of Conduct","ref":"CODE_OF_CONDUCT.md.html#scope"},{"type":"extras","doc":"Instances of abusive, harassing, or otherwise unacceptable behavior may be\nreported to the community leaders responsible for enforcement at [INSERT CONTACT\nMETHOD]. All complaints will be reviewed and investigated promptly and fairly.\n\nAll community leaders are obligated to respect the privacy and security of the\nreporter of any incident.","title":"Enforcement - Code of Conduct","ref":"CODE_OF_CONDUCT.md.html#enforcement"},{"type":"extras","doc":"Community leaders will follow these Community Impact Guidelines in determining\nthe consequences for any action they deem in violation of this Code of Conduct:","title":"Enforcement Guidelines - Code of Conduct","ref":"CODE_OF_CONDUCT.md.html#enforcement-guidelines"},{"type":"extras","doc":"**Community Impact**: Use of inappropriate language or other behavior deemed\nunprofessional or unwelcome in the community.\n\n**Consequence**: A private, written warning from community leaders, providing\nclarity around the nature of the violation and an explanation of why the\nbehavior was inappropriate. A public apology may be requested.","title":"1. Correction - Code of Conduct","ref":"CODE_OF_CONDUCT.md.html#1-correction"},{"type":"extras","doc":"**Community Impact**: A violation through a single incident or series of\nactions.\n\n**Consequence**: A warning with consequences for continued behavior. No\ninteraction with the people involved, including unsolicited interaction with\nthose enforcing the Code of Conduct, for a specified period of time. This\nincludes avoiding interactions in community spaces as well as external channels\nlike social media. Violating these terms may lead to a temporary or permanent\nban.","title":"2. Warning - Code of Conduct","ref":"CODE_OF_CONDUCT.md.html#2-warning"},{"type":"extras","doc":"**Community Impact**: A serious violation of community standards, including\nsustained inappropriate behavior.\n\n**Consequence**: A temporary ban from any sort of interaction or public\ncommunication with the community for a specified period of time. No public or\nprivate interaction with the people involved, including unsolicited interaction\nwith those enforcing the Code of Conduct, is allowed during this period.\nViolating these terms may lead to a permanent ban.","title":"3. Temporary Ban - Code of Conduct","ref":"CODE_OF_CONDUCT.md.html#3-temporary-ban"},{"type":"extras","doc":"**Community Impact**: Demonstrating a pattern of violation of community\nstandards, including sustained inappropriate behavior, harassment of an\nindividual, or aggression toward or disparagement of classes of individuals.\n\n**Consequence**: A permanent ban from any sort of public interaction within the\ncommunity.","title":"4. Permanent Ban - Code of Conduct","ref":"CODE_OF_CONDUCT.md.html#4-permanent-ban"},{"type":"extras","doc":"This Code of Conduct is adapted from the [Contributor Covenant][homepage],\nversion 2.1, available at\n .\n\nCommunity Impact Guidelines were inspired by\n[Mozilla's code of conduct enforcement ladder][Mozilla CoC].\n\nFor answers to common questions about this code of conduct, see the FAQ at\n . Translations are available at\n .\n\n[homepage]: https://www.contributor-covenant.org\n[Mozilla CoC]: https://github.com/mozilla/diversity","title":"Attribution - Code of Conduct","ref":"CODE_OF_CONDUCT.md.html#attribution"},{"type":"extras","doc":"# Enviable Changelog","title":"CHANGELOG","ref":"CHANGELOG.md.html"},{"type":"extras","doc":"- Added `list` conversion for delimiter-separated lists. This supports all\n  options of `String.split/3`.\n\n- Added `*_env_as_TYPE/2` functions for all encoded conversions (`base16`,\n  `base32`, `hex32`, `base64`, `url_base64`, and `list`).\n\n- Internal:\n\n  - Added an internal config module to split the configuration from the\n    conversion code for improved readability.\n\n  - Updated doc names to how I now structure my projects.\n\n  - Add excoveralls for coverage.","title":"1.4.0 / 2025-02-11 - CHANGELOG","ref":"CHANGELOG.md.html#1-4-0-2025-02-11"},{"type":"extras","doc":"- Added explicit functions for retrieval and conversion of primitives to assist\n  with language servers and IDEs as an alternative to `*_env_as/3` functions.\n  Most of these new functions are `*_env_as_TYPE/2`, but several are\n  `*_env_as_TYPE/1` as there are no applicable options.\n\n  Encoded conversions (`:base*`) do not have named functions and must be\n  accessed through `*_env_as/3`.\n\n- Soft-deprecated `*_env_integer` and `*_env_boolean` functions in favour of\n  `*_env_as_integer` and `*_env_as_boolean`. There will be at least one release\n  of Enviable 1.x which marks these functions as deprecated so that compiler\n  warnings are generated.","title":"1.3.0 / 2025-01-16 - CHANGELOG","ref":"CHANGELOG.md.html#1-3-0-2025-01-16"},{"type":"extras","doc":"- Fixed a function definition bug with `fetch_env_as/3` and `fetch_env_as!/3`\n  preventing them from being `fetch_env_as/2` and `fetch_env_as!/2`.","title":"1.2.1 / 2025-01-02 - CHANGELOG","ref":"CHANGELOG.md.html#1-2-1-2025-01-02"},{"type":"extras","doc":"- Added conversions for `log_level`.\n- Add Elixir 1.18 / OTP 27 to the test matrix.\n- Update dependencies.\n- Add mise configuration.\n- Fix dialyzer configuration.","title":"1.2.0 / 2024-12-29 - CHANGELOG","ref":"CHANGELOG.md.html#1-2-0-2024-12-29"},{"type":"extras","doc":"- Extended conversions through `get_env_as/3`, `fetch_env_as/3`, and\n  `fetch_env_as!/3`.\n\n- Fixed more documentation issues.","title":"1.1.0 / 2024-12-22 - CHANGELOG","ref":"CHANGELOG.md.html#1-1-0-2024-12-22"},{"type":"extras","doc":"- Fixed documentation issues.","title":"1.0.1 / 2024-12-11 - CHANGELOG","ref":"CHANGELOG.md.html#1-0-1-2024-12-11"},{"type":"extras","doc":"- Initial release.","title":"1.0.0 / 2024-12-10 - CHANGELOG","ref":"CHANGELOG.md.html#1-0-0-2024-12-10"},{"type":"extras","doc":"# Licence\n\nEnviable is copyright © 2024–2025 Austin Ziegler and is licensed under the\n[Apache License, version 2.0](licences/APACHE-2.0.txt). Portions of Enviable are\nadapted from the `System` module in [Elixir][elixir].","title":"Licence","ref":"LICENCE.md.html"},{"type":"extras","doc":"All contributors **must** certify they are willing and able to provide their\ncontributions under the terms of this project's licences with the certification\nof the [Developer Certificate of Origin (Version 1.1)](licences/dco.txt).\n\nSuch certification is provided by ensuring that a `Signed-off-by`\n[commit trailer][trailer] is present on every commit:\n\n    Signed-off-by: FirstName LastName  \n\nThe `Signed-off-by` trailer can be automatically added by git with the `-s` or\n`--signoff` option on `git commit`:\n\n```sh\ngit commit --signoff\n```\n\n[trailer]: https://git-scm.com/docs/git-interpret-trailers\n[elixir]: https://github.com/elixir-lang/elixir","title":"Developer Certificate of Origin - Licence","ref":"LICENCE.md.html#developer-certificate-of-origin"},{"type":"extras","doc":"Apache License\nVersion 2.0, January 2004\nhttp://www.apache.org/licenses/\n\nTERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n1. Definitions.\n\n\"License\" shall mean the terms and conditions for use, reproduction, and\ndistribution as defined by Sections 1 through 9 of this document.\n\n\"Licensor\" shall mean the copyright owner or entity authorized by the copyright\nowner that is granting the License.\n\n\"Legal Entity\" shall mean the union of the acting entity and all other entities\nthat control, are controlled by, or are under common control with that entity.\nFor the purposes of this definition, \"control\" means (i) the power, direct or\nindirect, to cause the direction or management of such entity, whether by\ncontract or otherwise, or (ii) ownership of fifty percent (50%) or more of the\noutstanding shares, or (iii) beneficial ownership of such entity.\n\n\"You\" (or \"Your\") shall mean an individual or Legal Entity exercising\npermissions granted by this License.\n\n\"Source\" form shall mean the preferred form for making modifications, including\nbut not limited to software source code, documentation source, and configuration\nfiles.\n\n\"Object\" form shall mean any form resulting from mechanical transformation or\ntranslation of a Source form, including but not limited to compiled object code,\ngenerated documentation, and conversions to other media types.\n\n\"Work\" shall mean the work of authorship, whether in Source or Object form, made\navailable under the License, as indicated by a copyright notice that is included\nin or attached to the work (an example is provided in the Appendix below).\n\n\"Derivative Works\" shall mean any work, whether in Source or Object form, that\nis based on (or derived from) the Work and for which the editorial revisions,\nannotations, elaborations, or other modifications represent, as a whole, an\noriginal work of authorship. For the purposes of this License, Derivative Works\nshall not include works that remain separable from, or merely link (or bind by\nname) to the interfaces of, the Work and Derivative Works thereof.\n\n\"Contribution\" shall mean any work of authorship, including the original version\nof the Work and any modifications or additions to that Work or Derivative Works\nthereof, that is intentionally submitted to Licensor for inclusion in the Work\nby the copyright owner or by an individual or Legal Entity authorized to submit\non behalf of the copyright owner. For the purposes of this definition,\n\"submitted\" means any form of electronic, verbal, or written communication sent\nto the Licensor or its representatives, including but not limited to\ncommunication on electronic mailing lists, source code control systems, and\nissue tracking systems that are managed by, or on behalf of, the Licensor for\nthe purpose of discussing and improving the Work, but excluding communication\nthat is conspicuously marked or otherwise designated in writing by the copyright\nowner as \"Not a Contribution.\"\n\n\"Contributor\" shall mean Licensor and any individual or Legal Entity on behalf\nof whom a Contribution has been received by Licensor and subsequently\nincorporated within the Work.\n\n2. Grant of Copyright License.\n\nSubject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable copyright license to reproduce, prepare Derivative Works of,\npublicly display, publicly perform, sublicense, and distribute the Work and such\nDerivative Works in Source or Object form.\n\n3. Grant of Patent License.\n\nSubject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable (except as stated in this section) patent license to make, have\nmade, use, offer to sell, sell, import, and otherwise transfer the Work, where\nsuch license applies only to those patent claims licensable by such Contributor\nthat are necessarily infringed by their Contribution(s) alone or by combination\nof their Contribution(s) with the Work to which such Contribution(s) was\nsubmitted. If You institute patent litigation against any entity (including\na cross-claim or counterclaim in a lawsuit) alleging that the Work or\na Contribution incorporated within the Work constitutes direct or contributory\npatent infringement, then any patent licenses granted to You under this License\nfor that Work shall terminate as of the date such litigation is filed.\n\n4. Redistribution.\n\nYou may reproduce and distribute copies of the Work or Derivative Works thereof\nin any medium, with or without modifications, and in Source or Object form,\nprovided that You meet the following conditions:\n\n- You must give any other recipients of the Work or Derivative Works a copy of\n  this License; and\n- You must cause any modified files to carry prominent notices stating that You\n  changed the files; and\n- You must retain, in the Source form of any Derivative Works that You\n  distribute, all copyright, patent, trademark, and attribution notices from the\n  Source form of the Work, excluding those notices that do not pertain to any\n  part of the Derivative Works; and\n- If the Work includes a \"NOTICE\" text file as part of its distribution, then\n  any Derivative Works that You distribute must include a readable copy of the\n  attribution notices contained within such NOTICE file, excluding those notices\n  that do not pertain to any part of the Derivative Works, in at least one of\n  the following places: within a NOTICE text file distributed as part of the\n  Derivative Works; within the Source form or documentation, if provided along\n  with the Derivative Works; or, within a display generated by the Derivative\n  Works, if and wherever such third-party notices normally appear. The contents\n  of the NOTICE file are for informational purposes only and do not modify the\n  License. You may add Your own attribution notices within Derivative Works that\n  You distribute, alongside or as an addendum to the NOTICE text from the Work,\n  provided that such additional attribution notices cannot be construed as\n  modifying the License.\n\nYou may add Your own copyright statement to Your modifications and may provide\nadditional or different license terms and conditions for use, reproduction, or\ndistribution of Your modifications, or for any such Derivative Works as a whole,\nprovided Your use, reproduction, and distribution of the Work otherwise complies\nwith the conditions stated in this License.\n\n5. Submission of Contributions.\n\nUnless You explicitly state otherwise, any Contribution intentionally submitted\nfor inclusion in the Work by You to the Licensor shall be under the terms and\nconditions of this License, without any additional terms or conditions.\nNotwithstanding the above, nothing herein shall supersede or modify the terms of\nany separate license agreement you may have executed with Licensor regarding\nsuch Contributions.\n\n6. Trademarks.\n\nThis License does not grant permission to use the trade names, trademarks,\nservice marks, or product names of the Licensor, except as required for\nreasonable and customary use in describing the origin of the Work and\nreproducing the content of the NOTICE file.\n\n7. Disclaimer of Warranty.\n\nUnless required by applicable law or agreed to in writing, Licensor provides the\nWork (and each Contributor provides its Contributions) on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied,\nincluding, without limitation, any warranties or conditions of TITLE,\nNON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are\nsolely responsible for determining the appropriateness of using or\nredistributing the Work and assume any risks associated with Your exercise of\npermissions under this License.\n\n8. Limitation of Liability.\n\nIn no event and under no legal theory, whether in tort (including negligence),\ncontract, or otherwise, unless required by applicable law (such as deliberate\nand grossly negligent acts) or agreed to in writing, shall any Contributor be\nliable to You for damages, including any direct, indirect, special, incidental,\nor consequential damages of any character arising as a result of this License or\nout of the use or inability to use the Work (including but not limited to\ndamages for loss of goodwill, work stoppage, computer failure or malfunction, or\nany and all other commercial damages or losses), even if such Contributor has\nbeen advised of the possibility of such damages.\n\n9. Accepting Warranty or Additional Liability.\n\nWhile redistributing the Work or Derivative Works thereof, You may choose to\noffer, and charge a fee for, acceptance of support, warranty, indemnity, or\nother liability obligations and/or rights consistent with this License. However,\nin accepting such obligations, You may act only on Your own behalf and on Your\nsole responsibility, not on behalf of any other Contributor, and only if You\nagree to indemnify, defend, and hold each Contributor harmless for any liability\nincurred by, or claims asserted against, such Contributor by reason of your\naccepting any such warranty or additional liability.\n\nEND OF TERMS AND CONDITIONS","title":"Apache License, version 2.0","ref":"APACHE-2.0.txt.html"},{"type":"extras","doc":"Developer Certificate of Origin\nVersion 1.1\n\nCopyright (C) 2004, 2006 The Linux Foundation and its contributors.\n\nEveryone is permitted to copy and distribute verbatim copies of this\nlicense document, but changing it is not allowed.\n\n\nDeveloper's Certificate of Origin 1.1\n\nBy making a contribution to this project, I certify that:\n\n(a) The contribution was created in whole or in part by me and I\n    have the right to submit it under the open source license\n    indicated in the file; or\n\n(b) The contribution is based upon previous work that, to the best\n    of my knowledge, is covered under an appropriate open source\n    license and I have the right under that license to submit that\n    work with modifications, whether created in whole or in part\n    by me, under the same open source license (unless I am\n    permitted to submit under a different license), as indicated\n    in the file; or\n\n(c) The contribution was provided directly to me by some other\n    person who certified (a), (b) or (c) and I have not modified\n    it.\n\n(d) I understand and agree that this project and the contribution\n    are public and that a record of the contribution (including all\n    personal information I submit with it, including my sign-off) is\n    maintained indefinitely and may be redistributed consistent with\n    this project or the open source license(s) involved.","title":"Developer Certificate of Origin","ref":"dco.txt.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.1"}}